@@ -28,7 +28,7 @@
 using namespace LIFEO;
 
 // DIALOG SAVE GENERIC =============================================================================
-DialogSaveGeneric::DialogSaveGeneric( const Glib::ustring &title )
+DialogSaveGeneric::DialogSaveGeneric( const Glib::ustring& title )
 :   Gtk::FileChooserDialog( title, Gtk::FILE_CHOOSER_ACTION_SAVE )
 {
     add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
@@ -46,7 +46,7 @@ DialogSaveGeneric::DialogSaveGeneric( BaseObjectType* cobject,
 }
 
 std::string
-DialogSaveGeneric::get_filename( const std::string &extension )
+DialogSaveGeneric::get_filename( const std::string& extension )
 {
     std::string fname( FileChooserDialog::get_filename() );
 
@@ -85,10 +85,10 @@ DialogSaveDiary::DialogSaveDiary( BaseObjectType* cobject,
 }
 
 int
-DialogSaveDiary::launch( std::string &path, std::string &passphrase )
+DialogSaveDiary::launch( std::string& path, std::string& passphrase )
 {
     if( ptr  == NULL )
-        Lifeograph::builder->get_widget_derived( "filedialog_save", ptr );
+        Lifeograph::builder->get_widget_derived( "FD_save", ptr );
 
     ptr->set_current_folder( Glib::path_get_dirname( path ) );
     ptr->set_current_name( Glib::path_get_basename( path ) );
@@ -104,7 +104,7 @@ DialogSaveDiary::launch( std::string &path, std::string &passphrase )
 }
 
 void
-DialogSaveDiary::handle_encryption_toggled( void )
+DialogSaveDiary::handle_encryption_toggled()
 {
     bool active( m_check_encrypt->get_active() );
     m_grid_password->set_visible( active );
@@ -121,7 +121,7 @@ DialogSaveDiary::handle_encryption_toggled( void )
 }
 
 void
-DialogSaveDiary::handle_password_changed( void )
+DialogSaveDiary::handle_password_changed()
 {
     Glib::ustring passphrase( m_entry_password->get_text() );
     bool pass_ok( passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE &&
@@ -135,7 +135,7 @@ bool DialogOpenDiary::flag_filters_created = false;
 Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_any;
 Glib::RefPtr< Gtk::FileFilter > DialogOpenDiary::filter_diary;
 
-DialogOpenDiary::DialogOpenDiary( void )
+DialogOpenDiary::DialogOpenDiary()
     // TRANSLATORS: this is the title of file chooser dialog for selecting a new diary
 :   Gtk::FileChooserDialog( _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN )
 {
@@ -155,7 +155,7 @@ DialogOpenDiary::DialogOpenDiary( void )
 }
 
 void
-DialogOpenDiary::init_filters( void )
+DialogOpenDiary::init_filters()
 {
     if( flag_filters_created )
         return;
@@ -172,7 +172,7 @@ DialogOpenDiary::init_filters( void )
 }
 
 void
-DialogOpenDiary::handle_selection_changed( void )
+DialogOpenDiary::handle_selection_changed()
 {
     bool flag_enable( get_filename().size() > 0 );  // check if anything is selected
     if( flag_enable )
@@ -184,24 +184,19 @@ DialogOpenDiary::handle_selection_changed( void )
 
 // DIALOG IMPORT ===================================================================================
 DialogImport::DialogImport( BaseObjectType* cobject,
-                            const Glib::RefPtr< Gtk::Builder > &refbuilder )
+                            const Glib::RefPtr< Gtk::Builder >& refbuilder )
 :   DialogEvent( cobject, refbuilder ), m_dialog_password( NULL ), m_diary( NULL )
 {
-    Lifeograph::builder->get_widget( "filebutton_import_diary",
-            m_file_chooser_button );
-    Lifeograph::builder->get_widget( "label_import_info", m_label_info );
-    Lifeograph::builder->get_widget( "label_import_entries", m_label_entries );
-    Lifeograph::builder->get_widget( "label_import_tags", m_label_tags );
-    Lifeograph::builder->get_widget( "label_import_themes", m_label_themes );
-    Lifeograph::builder->get_widget_derived( "entry_import_add_tag",
-            m_tag_widget );
+    refbuilder->get_widget( "FB_import_diary", m_file_chooser_button );
+    refbuilder->get_widget( "L_import_info", m_label_info );
+    refbuilder->get_widget( "L_import_entries", m_label_entries );
+    refbuilder->get_widget( "L_import_tags", m_label_tags );
+    refbuilder->get_widget( "L_import_chapters", m_label_chapters );
+    refbuilder->get_widget_derived( "E_import_add_tag", m_tag_widget );
 
-    Lifeograph::builder->get_widget( "checkbutton_import_entries",
-            m_checkbutton_import_entries );
-    Lifeograph::builder->get_widget( "checkbutton_import_tags",
-            m_checkbutton_import_tags );
-    Lifeograph::builder->get_widget( "checkbutton_import_themes",
-            m_checkbutton_import_themes );
+    refbuilder->get_widget( "CB_import_entries", m_checkbutton_import_entries );
+    refbuilder->get_widget( "CB_import_tags", m_checkbutton_import_tags );
+    refbuilder->get_widget( "CB_import_chapters", m_checkbutton_import_chapters );
 
     // FILTERING
     DialogOpenDiary::init_filters();
@@ -217,18 +212,18 @@ DialogImport::DialogImport( BaseObjectType* cobject,
             sigc::mem_fun( this, &DialogImport::handle_parts_changed ) );
     m_checkbutton_import_tags->signal_toggled().connect(
             sigc::mem_fun( this, &DialogImport::handle_parts_changed ) );
-    m_checkbutton_import_themes->signal_toggled().connect(
+    m_checkbutton_import_chapters->signal_toggled().connect(
             sigc::mem_fun( this, &DialogImport::handle_parts_changed ) );
 }
 
 inline bool
-DialogImport::is_options_ready( void )
+DialogImport::is_options_ready()
 {
-    return( m_option_import_entries || m_option_import_tags || m_option_import_themes );
+    return( m_option_import_entries || m_option_import_tags || m_option_import_chapters );
 }
 
 void
-DialogImport::on_show( void )
+DialogImport::on_show()
 {
     Gtk::Dialog::on_show();
     set_not_ready( _( "Select a diary file for importing" ) );
@@ -238,7 +233,7 @@ DialogImport::on_show( void )
 
     m_checkbutton_import_entries->set_active( true );
     m_checkbutton_import_tags->set_active( true );
-    m_checkbutton_import_themes->set_active( true );
+    m_checkbutton_import_chapters->set_active( true );
 
     m_tag_widget->populate();
 
@@ -246,7 +241,7 @@ DialogImport::on_show( void )
 }
 
 void
-DialogImport::handle_diary_changed( void )
+DialogImport::handle_diary_changed()
 {
     if( m_diary != NULL )
         delete m_diary;
@@ -284,40 +279,50 @@ DialogImport::handle_diary_changed( void )
 }
 
 void
-DialogImport::handle_parts_changed( void )
+DialogImport::handle_parts_changed()
 {
     m_option_import_entries = m_checkbutton_import_entries->get_active();
     m_option_import_tags = m_checkbutton_import_tags->get_active();
-    m_option_import_themes = m_checkbutton_import_themes->get_active();
+    m_option_import_chapters = m_checkbutton_import_chapters->get_active();
+
+    m_tag_widget->set_sensitive( m_option_import_entries );
 
     set_response_sensitive( RESPONSE_GO,
             m_flag_diary_is_ready && is_options_ready() );
 }
 
 void
-DialogImport::set_ready( void )
+DialogImport::set_ready()
 {
     set_response_sensitive( RESPONSE_GO, is_options_ready() );
 
+    int n_chapters = 0;
+    for( PoolCategoriesChapters::const_iterator i_cc = m_diary->m_chapter_categories.begin();
+         i_cc != m_diary->m_chapter_categories.end();
+         ++i_cc)
+    {
+        n_chapters += i_cc->second->size();
+    }
+
     m_label_entries->set_text(
             Glib::ustring::compose( "%1", m_diary->get_size() ) );
     m_label_tags->set_text(
             Glib::ustring::compose( "%1", m_diary->get_tags()->size() ) );
-    m_label_themes->set_text(
-            Glib::ustring::compose( "%1", m_diary->m_themes.size() - 1 ) );
+    m_label_chapters->set_text(
+            Glib::ustring::compose( "%1/%2", n_chapters, m_diary->m_chapter_categories.size() ) );
 
     m_label_info->set_text( _( "Diary is ready for importing" ) );
     m_flag_diary_is_ready = true;
 }
 
 void
-DialogImport::set_not_ready( const Glib::ustring &message )
+DialogImport::set_not_ready( const Glib::ustring& message )
 {
     set_response_sensitive( RESPONSE_GO, false );
 
     m_label_entries->set_text( "-" );
     m_label_tags->set_text( "-" );
-    m_label_themes->set_text( "-" );
+    m_label_chapters->set_text( "-" );
 
     if( m_diary )
     {
@@ -334,7 +339,7 @@ DialogImport::on_response( int response )
 {
     if( response == RESPONSE_GO )
     {
-        if( m_option_import_tags )
+        if( m_option_import_tags )  // tags need to come before entries
         {
             for( PoolTags::const_iterator iter = m_diary->m_tags.begin();
                     iter != m_diary->m_tags.end(); ++iter )
@@ -343,16 +348,16 @@ DialogImport::on_response( int response )
             }
         }
 
-        if( m_option_import_themes )
-        {
-            Diary::d->import_themes( m_diary->m_themes );
-        }
-
         if( m_option_import_entries )
         {
             Diary::d->import_entries( *m_diary, m_option_import_tags,
                     m_tag_widget->get_text() );
         }
+
+        if( m_option_import_chapters )
+        {
+            Diary::d->import_chapters( *m_diary );
+        }
     }
 
     delete m_diary;
@@ -363,7 +368,7 @@ DialogImport::on_response( int response )
 
 // DIALOG EXPORT ===================================================================================
 DialogExport::DialogExport( BaseObjectType* cobject,
-        const Glib::RefPtr< Gtk::Builder > &refbuilder )
+        const Glib::RefPtr< Gtk::Builder >& refbuilder )
 :   DialogEvent( cobject, refbuilder ), m_ptr2widget_options( NULL ), m_ptr2diary( Diary::d )
 {
     Lifeograph::builder->get_widget( "combo_export_type", m_combo_type );
@@ -386,7 +391,7 @@ DialogExport::DialogExport( BaseObjectType* cobject,
 }
 
 void
-DialogExport::add_saver( Diarysaver *saver )
+DialogExport::add_saver( Diarysaver* saver )
 {
     m_savers.push_back( saver );
     m_combo_type->append( saver->get_name() );
@@ -402,7 +407,7 @@ DialogExport::handle_saver_updated( bool ready )
 }
 
 void
-DialogExport::handle_savetype_changed( void )
+DialogExport::handle_savetype_changed()
 {
     m_saver_cur = m_savers[ m_combo_type->get_active_row_number() ];
 
@@ -440,19 +445,19 @@ DialogExport::on_response( int response )
 }
 
 // EXPORTERS =======================================================================================
-Diarysaver::Diarysaver( const Glib::ustring& name, Diary *diary )
-        : m_name( name ), m_ptr2diary( diary )
+Diarysaver::Diarysaver( const Glib::ustring& name, Diary* diary )
+:   m_name( name ), m_ptr2diary( diary )
 {
 }
 
-ExporterLifeograph::ExporterLifeograph( Diary *diary )
+ExporterLifeograph::ExporterLifeograph( Diary* diary )
 :   Diarysaver( _( "Lifeograph Diary File" ), diary ) //, m_passphrase( "" ),
     //m_flag_encrypted( false )
 {
 }
 
 Gtk::Widget*
-ExporterLifeograph::draw_options( void )
+ExporterLifeograph::draw_options()
 {
     /*m_entry_passphrase = Gtk::manage( new Gtk::Entry );
     m_entry_confirm = Gtk::manage( new Gtk::Entry );
@@ -491,14 +496,14 @@ ExporterLifeograph::draw_options( void )
 }
 
 bool
-ExporterLifeograph::is_ready( void )
+ExporterLifeograph::is_ready()
 {
     //return( ( ! m_flag_encrypted ) || m_passphrase.size() >= LIFEO::PASSPHRASE_MIN_SIZE );
     return true;
 }
 
 /*void
-ExporterLifeograph::handle_passphrase_changed( void )
+ExporterLifeograph::handle_passphrase_changed()
 {
     m_passphrase = m_entry_passphrase->get_text();
     if( m_passphrase != m_entry_confirm->get_text() )
@@ -511,7 +516,7 @@ ExporterLifeograph::handle_passphrase_changed( void )
 }
 
 void
-ExporterLifeograph::handle_encryption_changed( void )
+ExporterLifeograph::handle_encryption_changed()
 {
     m_flag_encrypted = m_check_encrypt->get_active();
     m_entry_passphrase->set_sensitive( m_flag_encrypted );
@@ -536,7 +541,7 @@ ExporterLifeograph::save( bool filtered )
         return m_ptr2diary->write_copy( path, "", filtered );
 }
 
-ExporterText::ExporterText( Diary *diary )
+ExporterText::ExporterText( Diary* diary )
         : Diarysaver( _( "Plain Text File" ), diary )
 {
 
