@@ -97,17 +97,24 @@ Diary::~Diary()
     remove_lock();
 }
 
-void
+Result
 Diary::init_new( const std::string& path )
 {
     clear();
+    Result result( set_path( path, true ) );
 
-    if( set_path( path, true ) != LIFEO::SUCCESS )
-        throw( LIFEO::Error( "Path could not set" ) );
+    if( result != LIFEO::SUCCESS )
+    {
+        clear();
+        return result;
+    }
 
-    add_today();
     // every diary must at least have one chapter category:
     m_ptr2chapter_ctg_cur = create_chapter_ctg( _( DEFAULT_CHAPTER_CTG_NAME ) );
+
+    add_today();
+    
+    return LIFEO::SUCCESS;
 }
 
 void
@@ -385,64 +392,69 @@ Diary::read_encrypted()
     file.seekg( m_body_position );
 
     std::string line, content;
-    unsigned char *buffer;
-    try {
+    CipherBuffers buf;
+
+    try
+    {
         // Allocate memory for salt
-        unsigned char *salt = new unsigned char[ LIFEO::Cipher::cSALT_SIZE ];
-        if( ! salt )
+        buf.salt = new unsigned char[ LIFEO::Cipher::cSALT_SIZE ];
+        if( ! buf.salt )
             throw LIFEO::Error( "Unable to allocate memory for salt" );
         // Read salt value
-        file.read( (char*) salt, LIFEO::Cipher::cSALT_SIZE );
+        file.read( ( char* ) buf.salt, LIFEO::Cipher::cSALT_SIZE );
 
-        unsigned char *iv = new unsigned char[ LIFEO::Cipher::cIV_SIZE ];
-        if( ! iv )
+        buf.iv = new unsigned char[ LIFEO::Cipher::cIV_SIZE ];
+        if( ! buf.iv )
             throw LIFEO::Error( "Unable to allocate memory for IV" );
         // Read IV
-        file.read( (char*) iv, LIFEO::Cipher::cIV_SIZE );
+        file.read( ( char* ) buf.iv, LIFEO::Cipher::cIV_SIZE );
 
-        unsigned char *key;
-        LIFEO::Cipher::expand_key( m_passphrase.c_str(), salt, &key );
+        LIFEO::Cipher::expand_key( m_passphrase.c_str(), buf.salt, &buf.key );
 
         // Calulate bytes of data in file
         size_t size = LIFEO::get_file_size( file ) - file.tellg();
         if( size <= 3 )
         {
             file.close();
+            buf.clear();
             return LIFEO::CORRUPT_FILE;
         }
-        buffer = new unsigned char[ size + 1 ];
-        // TODO(<0.4.0): ex handling here!!!
+        buf.buffer = new unsigned char[ size + 1 ];
+        if( ! buf.buffer )
+            throw LIFEO::Error( "Unable to allocate memory for buffer" );
 
-        file.read( (char*) buffer, size );
-        LIFEO::Cipher::decrypt_buffer( buffer, size, key, iv );
+        file.read( ( char* ) buf.buffer, size );
+        LIFEO::Cipher::decrypt_buffer( buf.buffer, size, buf.key, buf.iv );
         file.close();
 
         // passphrase check
-        if( buffer[ 0 ] != m_passphrase[ 0 ] && buffer[ 1 ] != '\n' )
+        if( buf.buffer[ 0 ] != m_passphrase[ 0 ] && buf.buffer[ 1 ] != '\n' )
         {
+            buf.clear();
             return LIFEO::WRONG_PASSWORD;
         }
 
-        buffer[ size ] = 0;   // terminating zero
+        buf.buffer[ size ] = 0;   // terminating zero
     }
     catch( ... )
     {
+        buf.clear();
         return LIFEO::COULD_NOT_START;
     }
 
     std::stringstream stream;
-    buffer += 2;    // ignore first two chars which are for passphrase checking
-    stream << buffer;
-    buffer -= 2;    // restore pointer to the start of the buffer before deletion
-    delete[] buffer;
+    buf.buffer += 2;    // ignore first two chars which are for passphrase checking
+    stream << buf.buffer;
+    buf.buffer -= 2;    // restore pointer to the start of the buffer before deletion
 
+    buf.clear();
     return parse_db_body_text( stream );
 }
 
 inline LIFEO::Result
 Diary::parse_db_body_text( std::stringstream& stream )
 {
-    if( m_read_version == 1010 )
+    if( m_read_version == 1010 || m_read_version == 1011 )
         return parse_db_body_text_1010( stream );
     else if( m_read_version == 56 )
         return parse_db_body_text_56( stream );
@@ -484,6 +496,9 @@ Diary::parse_db_body_text_1010( std::stringstream& stream )
                 case 't':   // tag
                     ptr2tag = create_tag( line.substr( 2 ), ptr2tag_ctg );
                     break;
+                case 'u':
+                    ptr2tag = &m_untagged;
+                    // no break
                 case 'm':
                     if( ptr2tag == NULL )
                     {
@@ -1161,7 +1176,6 @@ Diary::write()
     }
 
     // WRITE THE FILE
-    m_flag_only_save_filtered = false;
     Result result( write( m_path ) );
 
     // DAILY BACKUP SAVES
@@ -1177,6 +1191,8 @@ Diary::write()
 LIFEO::Result
 Diary::write( const std::string& path )
 {
+    m_flag_only_save_filtered = false;
+
     if( m_passphrase.empty() )
         return write_plain( path );
     else
@@ -1327,6 +1343,8 @@ Diary::write_encrypted( const std::string& path )
         return LIFEO::COULD_NOT_START;
     }
     std::stringstream output;
+    CipherBuffers buf;
+
     // first char of passphrase for validity checking
     output << m_passphrase[ 0 ] << '\n';
     create_db_body_text( output );
@@ -1335,30 +1353,27 @@ Diary::write_encrypted( const std::string& path )
     try {
         size_t size =  output.str().size() + 1;
 
-        unsigned char* key;
-        unsigned char* salt;
-        LIFEO::Cipher::create_new_key( m_passphrase.c_str(), &salt, &key );
+        LIFEO::Cipher::create_new_key( m_passphrase.c_str(), &buf.salt, &buf.key );
 
-        unsigned char* iv;
-        LIFEO::Cipher::create_iv( &iv );
+        LIFEO::Cipher::create_iv( &buf.iv );
 
-        unsigned char* buffer = new unsigned char[ size ];
-        memcpy( buffer, output.str().c_str(), size );
+        buf.buffer = new unsigned char[ size ];
+        memcpy( buf.buffer, output.str().c_str(), size );
 
-        LIFEO::Cipher::encrypt_buffer( buffer, size, key, iv );
-
-        file.write( ( char* ) salt, LIFEO::Cipher::cSALT_SIZE );
-        file.write( ( char* ) iv, LIFEO::Cipher::cIV_SIZE );
-        file.write( ( char* ) buffer, size );
+        LIFEO::Cipher::encrypt_buffer( buf.buffer, size, buf.key, buf.iv );
 
+        file.write( ( char* ) buf.salt, LIFEO::Cipher::cSALT_SIZE );
+        file.write( ( char* ) buf.iv, LIFEO::Cipher::cIV_SIZE );
+        file.write( ( char* ) buf.buffer, size );
     }
     catch( ... )
     {
+        buf.clear();
         return LIFEO::FAILURE;
     }
 
     file.close();
-
+    buf.clear();
     return LIFEO::SUCCESS;
 }
 
@@ -1374,19 +1389,21 @@ Diary::create_db_header_text( std::stringstream &output, bool encrypted )
 }
 
 inline void
-Diary::create_db_tag_text( const Tag* tag, std::stringstream& output )
+Diary::create_db_tag_text( char type, const Tag* tag, std::stringstream& output )
 {
-    output << "ID" << tag->get_id() << "\nt " << tag->get_name_std() << '\n';
+    if( type == 'm' )
+        output << "ID" << tag->get_id() << "\nt " << tag->get_name_std() << '\n';
+
     if( tag->get_has_own_theme() )
     {
         Theme* theme( tag->get_theme() );
 
-        output << "mf" << theme->font.to_string() << '\n';
-        output << "mb" << convert_gdkrgba_to_string( theme->color_base ) << '\n';
-        output << "mt" << convert_gdkrgba_to_string( theme->color_text ) << '\n';
-        output << "mh" << convert_gdkrgba_to_string( theme->color_heading ) << '\n';
-        output << "ms" << convert_gdkrgba_to_string( theme->color_subheading ) << '\n';
-        output << "ml" << convert_gdkrgba_to_string( theme->color_highlight ) << '\n';
+        output << type << 'f' << theme->font.to_string() << '\n';
+        output << type << 'b' << convert_gdkrgba_to_string( theme->color_base ) << '\n';
+        output << type << 't' << convert_gdkrgba_to_string( theme->color_text ) << '\n';
+        output << type << 'h' << convert_gdkrgba_to_string( theme->color_heading ) << '\n';
+        output << type << 's' << convert_gdkrgba_to_string( theme->color_subheading ) << '\n';
+        output << type << 'l' << convert_gdkrgba_to_string( theme->color_highlight ) << '\n';
     }
 }
 
@@ -1408,7 +1425,7 @@ Diary::create_db_body_text( std::stringstream& output )
          ++iter )
     {
         if( iter->second->get_category() == NULL )
-            create_db_tag_text( iter->second, output );
+            create_db_tag_text( 'm', iter->second, output );
     }
     // CATEGORIZED TAGS
     for( PoolCategoriesTags::const_iterator iter = m_tag_categories.begin();
@@ -1425,9 +1442,12 @@ Diary::create_db_body_text( std::stringstream& output )
              iter_tag != ctg->end();
              ++iter_tag )
         {
-            create_db_tag_text( *iter_tag, output );
+            create_db_tag_text( 'm', *iter_tag, output );
         }
     }
+    // UNTAGGED THEME
+    create_db_tag_text( 'u', &m_untagged, output );
+
     // TOPICS
     for( CategoryChapters::iterator iter_chapter = m_topics.begin();
          iter_chapter != m_topics.end();
@@ -1793,7 +1813,7 @@ Diary::dismiss_entry( Entry* entry )
 {
     Date::date_t date = entry->get_date().m_date;
 
-    // fix startup element
+    // fix startup element:
     if( m_startup_elem_id == entry->get_id() )
         m_startup_elem_id = DEID_MIN;
 
@@ -1803,6 +1823,12 @@ Diary::dismiss_entry( Entry* entry )
          ++iter )
         ( *iter )->get_items()->erase( entry );
 
+    // remove from filters:
+    if( m_filter_active->is_entry_filtered( entry ) )
+        m_filter_active->remove_entry( entry );
+    if( m_filter_default->is_entry_filtered( entry ) )
+        m_filter_default->remove_entry( entry );
+
     // erase entry from map:
     m_entries.erase( date );
 
@@ -1959,9 +1985,11 @@ Diary::dismiss_tag( Tag* tag, bool flag_dismiss_associated )
     if( tag->get_category() != NULL )
         tag->get_category()->erase( tag );
 
-    // clear filter if necessary
+    // clear filters if necessary
     if( tag == m_filter_active->get_tag() )
         m_filter_active->set_tag( NULL );
+    if( tag == m_filter_default->get_tag() )
+        m_filter_default->set_tag( NULL );
 
     m_tags.erase( tag->get_name() );
     delete tag;
@@ -2017,9 +2045,8 @@ CategoryChapters*
 Diary::create_chapter_ctg()
 {
     Glib::ustring name = create_unique_name_for_map( m_chapter_categories, _( "New category" ) );
-    CategoryChapters *category = new CategoryChapters( this, name );
-    m_chapter_categories.insert(
-            PoolCategoriesChapters::value_type( name, category ) );
+    CategoryChapters* category = new CategoryChapters( this, name );
+    m_chapter_categories.insert( PoolCategoriesChapters::value_type( name, category ) );
 
     return category;
 }
@@ -2067,12 +2094,15 @@ Diary::rename_chapter_ctg( CategoryChapters* category, const Glib::ustring& name
 void
 Diary::dismiss_chapter( Chapter* chapter, bool flag_dismiss_contained )
 {
-    if( chapter->is_ordinal() ) // TOPIC
+    if( chapter->is_ordinal() ) // TOPIC OR TODO GROUP
     {
+        CategoryChapters* ptr2ctg( chapter->get_date().is_todo() ?
+                &m_todo_groups : &m_topics );
+
         // ORDER SHIFTING TO PRESERVE CONTINUITY
-        if( m_topics.size() == 1 )  // must be handled separately
+        if( ptr2ctg->size() == 1 )  // must be handled separately
         {
-            m_topics.erase( chapter->get_date().m_date );
+            ptr2ctg->erase( chapter->get_date().m_date );
             delete chapter;
             return;
         }
@@ -2080,12 +2110,12 @@ Diary::dismiss_chapter( Chapter* chapter, bool flag_dismiss_contained )
         // CALCULATE HELPER VALUES
         Date d_chapter( chapter->get_date() );
         Date::date_t d_chapter_next( d_chapter.m_date + Date::ORDINAL_STEP );
-        bool flag_last_chapter( m_topics.find( d_chapter_next ) == m_topics.end() );
+        bool flag_last_chapter( ptr2ctg->find( d_chapter_next ) == ptr2ctg->end() );
 
         int last_order_of_prev_chapter( 0 );
         if( flag_last_chapter )
         {
-            Chapter *chapter_prev( m_topics.get_chapter(
+            Chapter* chapter_prev( ptr2ctg->get_chapter(
                     d_chapter.m_date - Date::ORDINAL_STEP ) );
             Date d_first_free( chapter_prev->get_free_order() );
             last_order_of_prev_chapter = d_first_free.get_order() - 1;
@@ -2097,20 +2127,20 @@ Diary::dismiss_chapter( Chapter* chapter, bool flag_dismiss_contained )
         }
 
         // ACTUALLY DISMISS THE TOPIC
-        m_topics.erase( chapter->get_date().m_date );
+        ptr2ctg->erase( chapter->get_date().m_date );
         delete chapter;
 
         // SHIFT TOPICS
         for( Date::date_t d = d_chapter.m_date + Date::ORDINAL_STEP; ;
              d += Date::ORDINAL_STEP )
         {
-            CategoryChapters::iterator iter( m_topics.find( d ) );
-            if( iter == m_topics.end() )
+            CategoryChapters::iterator iter( ptr2ctg->find( d ) );
+            if( iter == ptr2ctg->end() )
                 break;
-            Chapter *chpt( iter->second );
-            m_topics.erase( d );
+            Chapter* chpt( iter->second );
+            ptr2ctg->erase( d );
             chpt->set_date( d - Date::ORDINAL_STEP );
-            m_topics[ d - Date::ORDINAL_STEP ] = chpt;
+            ( *ptr2ctg )[ d - Date::ORDINAL_STEP ] = chpt;
         }
 
         // SHIFT ENTRIES
@@ -2154,7 +2184,7 @@ Diary::dismiss_chapter( Chapter* chapter, bool flag_dismiss_contained )
             }
         }
     }
-    else // TEMPORAL CHAPTER i.e. NOT TOPIC
+    else // TEMPORAL CHAPTER
     {
         if( flag_dismiss_contained )
         {
@@ -2216,6 +2246,8 @@ Diary::set_topic_order( Chapter* chapter, Date::date_t date )
 {
     assert( chapter->is_ordinal() );
 
+    CategoryChapters* ptr2ctg( chapter->get_date().is_todo() ? &m_todo_groups : &m_topics );
+
     long step( chapter->get_date().m_date > date ? -Date::ORDINAL_STEP : Date::ORDINAL_STEP );
     EntryVector ev;
 
@@ -2224,7 +2256,7 @@ Diary::set_topic_order( Chapter* chapter, Date::date_t date )
 
     while( iter_entry != m_entries.end() )
     {
-        Entry *entry( iter_entry->second );
+        Entry* entry( iter_entry->second );
 
         m_entries.erase( d_e );
         ev.push_back( entry );
@@ -2232,24 +2264,24 @@ Diary::set_topic_order( Chapter* chapter, Date::date_t date )
         iter_entry = m_entries.find( ++d_e );
     }
 
-    m_topics.erase( chapter->get_date().m_date );
+    ptr2ctg->erase( chapter->get_date().m_date );
 
     // SHIFT TOPICS
     for( Date::date_t d = chapter->get_date().m_date + step; d != ( date + step ); d += step )
     {
-        CategoryChapters::iterator iter( m_topics.find( d ) );
-        if( iter == m_topics.end() )
+        CategoryChapters::iterator iter( ptr2ctg->find( d ) );
+        if( iter == ptr2ctg->end() )
             break;
-        Chapter *chpt( iter->second );
-        m_topics.erase( d );
+        Chapter* chpt( iter->second );
+        ptr2ctg->erase( d );
         chpt->set_date( d - step );
-        m_topics[ d - step ] = chpt;
+        ( *ptr2ctg )[ d - step ] = chpt;
 
         d_e = d + 1;
         iter_entry = m_entries.find( d_e );
         while( iter_entry != m_entries.end() )
         {
-            Entry *entry( iter_entry->second );
+            Entry* entry( iter_entry->second );
 
             m_entries.erase( d_e );
             entry->set_date( d_e - step );
@@ -2260,10 +2292,10 @@ Diary::set_topic_order( Chapter* chapter, Date::date_t date )
     }
 
     chapter->set_date( date );
-    m_topics[ date ] = chapter;
+    ( *ptr2ctg )[ date ] = chapter;
     for( EntryVectorIter i = ev.begin(); i != ev.end(); i++ )
     {
-        Entry *entry( *i );
+        Entry* entry( *i );
 
         entry->set_date( ++date );
         m_entries[ date ] = entry;
