@@ -32,7 +32,7 @@
 namespace LIFEO
 {
 const char                      DB_FILE_HEADER[] = "LIFEOGRAPHDB";
-const int                       DB_FILE_VERSION_INT( 1010 );
+const int                       DB_FILE_VERSION_INT( 1011 );
 const int                       DB_FILE_VERSION_INT_MIN( 56 );
 const std::string::size_type    PASSPHRASE_MIN_SIZE( 4 );
 const char                      LOCK_SUFFIX[] = ".~LOCK~";
@@ -80,7 +80,7 @@ class Diary : public DiaryBase, public DiaryElement
         bool	                is_old()
         { return( m_read_version < DB_FILE_VERSION_INT ); }
 
-        void                    init_new( const std::string& );
+        Result                  init_new( const std::string& );
 
         // DISK I/O
         LIFEO::Result           read_body();
@@ -250,7 +250,7 @@ class Diary : public DiaryBase, public DiaryElement
         // pseudo tag "untagged":
         Untagged                m_untagged;
 
-        void                    create_db_tag_text( const Tag*, std::stringstream& );
+        void                    create_db_tag_text( char, const Tag*, std::stringstream& );
         LIFEO::Result           parse_db_body_text( std::stringstream& );
         LIFEO::Result           parse_db_body_text_1010( std::stringstream& );
         LIFEO::Result           parse_db_body_text_110( std::stringstream& );
