@@ -33,11 +33,6 @@
 namespace LIFEO
 {
 
-namespace STRING
-{
-const char SYSTEM_THEME[] = "[ - 0 - ]";
-}
-
 using namespace HELPERS;
 
 typedef char SortingCriteria;
@@ -52,7 +47,56 @@ static const DEID HOME_CURRENT_ELEM = 1;    // element shown at startup
 static const DEID HOME_LAST_ELEM = 2;       // element shown at startup
 static const DEID HOME_FIXED_ELEM = 3;      // element shown at startup (defines boundary)
 
-class DiaryElement;	// forward declaration
+typedef unsigned long ElemStatus;
+namespace ES
+{
+    static const ElemStatus VOID             = 0x0;
+    static const ElemStatus EXPANDED         = 0x40;
+
+    static const ElemStatus NOT_FAVORED      = 0x100;
+    static const ElemStatus FAVORED          = 0x200;
+    static const ElemStatus FILTER_FAVORED   = NOT_FAVORED|FAVORED;
+    static const ElemStatus NOT_TRASHED      = 0x400;
+    static const ElemStatus TRASHED          = 0x800;
+    static const ElemStatus FILTER_TRASHED   = NOT_TRASHED|TRASHED;
+    static const ElemStatus TODO             = 0x1000;
+    static const ElemStatus DONE             = 0x2000;
+    static const ElemStatus CANCELED         = 0x4000;
+    static const ElemStatus FILTER_TODO      = TODO|DONE|CANCELED;
+
+    static const ElemStatus DEFAULT          = NOT_FAVORED|NOT_TRASHED|TODO;
+    static const ElemStatus DEFAULT_FAVORED  = FAVORED|NOT_TRASHED|TODO;
+
+    // FILTER RELATED CONSTANTS AND ALIASES
+    static const ElemStatus SHOW_NOT_FAVORED    = NOT_FAVORED;
+    static const ElemStatus SHOW_FAVORED        = FAVORED;
+    static const ElemStatus SHOW_NOT_TRASHED    = NOT_TRASHED;
+    static const ElemStatus SHOW_TRASHED        = TRASHED;
+    static const ElemStatus SHOW_TODO           = TODO;
+    static const ElemStatus SHOW_DONE           = DONE;
+    static const ElemStatus SHOW_CANCELED       = CANCELED;
+
+    static const ElemStatus FILTER_TAG          = 0x100000;
+    static const ElemStatus FILTER_DATE_BEGIN   = 0x200000;
+    static const ElemStatus FILTER_DATE_END     = 0x400000;
+    static const ElemStatus FILTER_INDIVIDUAL   = 0x800000;
+    static const ElemStatus FILTER_OUTSTANDING  = 0x10000000;
+
+    static const ElemStatus FILTERED_OUT        = 0x80000000;
+
+    static const ElemStatus FILTER_DEFAULT      = FILTER_FAVORED|SHOW_NOT_TRASHED|SHOW_TODO;
+    static const ElemStatus FILTER_MAX          = 0xFFFFFFFF;
+}
+
+class DiaryElement;     // forward declaration
+class Untagged;         // forward declaration
+class Entry;            // forward decleration
+
+typedef std::vector< Entry* >               EntryVector;
+typedef std::vector< Entry* >::iterator     EntryVectorIter;
+
+typedef std::set< Entry* >                  EntrySet;
+typedef std::set< Entry* >::iterator        EntrySetIter;
 
 
 // DIARYBASE (FOR COMMUNICATION)
@@ -62,7 +106,7 @@ class DiaryBase
         typedef std::map< DEID, DiaryElement* >
                                     PoolDEIDs;
 
-                                    DiaryBase( void )
+                                    DiaryBase()
         :   m_current_id( DEID_MIN ), m_force_id( DEID_UNSET ), m_language( "" ) {}
         virtual                     ~DiaryBase() {}
 
@@ -92,7 +136,7 @@ class DiaryBase
             return true;
         }
 
-        void                        clear( void )
+        void                        clear()
         {
             m_force_id = DEID_UNSET;
             m_current_id = DEID_MIN;
@@ -101,9 +145,11 @@ class DiaryBase
 
         virtual bool                make_free_entry_order( Date& ) = 0;
 
-        std::string                 get_lang( void ) const { return m_language; }
+        std::string                 get_lang() const { return m_language; }
         void                        set_lang( const std::string &lang ) { m_language = lang; }
 
+        virtual Untagged*           get_untagged() = 0;
+
     protected:
         DEID                        m_current_id;
         DEID                        m_force_id;
@@ -118,13 +164,13 @@ class ListData;	// forward declaration
 class NamedElement
 {
     public:
-                                NamedElement( void ) : m_name( "" ) {}
+                                NamedElement() : m_name( "" ) {}
                                 NamedElement( const Glib::ustring &name ) : m_name( name ) {}
         virtual                 ~NamedElement() {}  //needed because of virtual methods
 
-        Glib::ustring           get_name( void ) const
+        Glib::ustring           get_name() const
         { return m_name; }
-        std::string             get_name_std( void ) const  // std::string version
+        std::string             get_name_std() const  // std::string version
         { return m_name; }
         void                    set_name( const Glib::ustring &name )
         { m_name = name; }
@@ -142,14 +188,15 @@ class DiaryElement : public NamedElement
 
         enum Type
         {   // CAUTION: order is significant and shouldn't be changed!
-            ET_NONE, ET_TAG, ET_TAG_CTG, ET_THEME, ET_CHAPTER_CTG,
+            ET_NONE, ET_TAG, ET_UNTAGGED, ET_TAG_CTG, ET_CHAPTER_CTG, ET_FILTER,
             // entry list elements:
-            ET_DIARY, ET_CHAPTER, ET_ENTRY, ET_DATE,
+            ET_DIARY, ET_CHAPTER, ET_TOPIC, ET_TODO_GRP, ET_ENTRY, ET_DATE,
             // special types for pseudo elements:
             ET_HEADER
         };
 
-                                DiaryElement( DiaryBase * const,
+                                DiaryElement( DiaryBase* const,
+                                              ElemStatus,
                                               const Glib::ustring& = "" );
         virtual                 ~DiaryElement()
         {
@@ -157,34 +204,40 @@ class DiaryElement : public NamedElement
                 m_ptr2diary->erase_id( m_id );
         }
 
-        virtual Date            get_date( void ) const
+        virtual Date            get_date() const
         { return Date( 0 ); }
-        virtual int             get_size( void ) const = 0;
-        virtual Type            get_type( void ) const = 0;
+        virtual int             get_size() const = 0;
+        virtual Type            get_type() const = 0;
         virtual const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon( void ) const
+                                get_icon() const
         { return( s_pixbuf_null ); }
         virtual const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32( void ) const
+                                get_icon32() const
         { return( s_pixbuf_null ); }
 
-        virtual Glib::ustring   get_list_str( void ) const
+        virtual Glib::ustring   get_list_str() const
         { return ""; }
 
-        DEID                    get_id( void ) const
+        DEID                    get_id() const
         { return m_id; }
 
-        virtual void            show( void ) = 0;
-        virtual void            prepare_for_hiding( void ) {}
-        virtual bool            get_filtered_out( void )
+        virtual void            show() = 0;
+        virtual void            prepare_for_hiding() {}
+        virtual bool            get_filtered_out()
         { return false; }
 
-        ListData                *m_list_data;
+        ElemStatus              get_status() const
+        { return m_status; }
+        void                    set_status( ElemStatus status )
+        { m_status = status; }
 
-        DiaryBase * const       m_ptr2diary;
+        ListData*               m_list_data;
+
+        DiaryBase* const        m_ptr2diary;
 
     protected:
         const DEID              m_id;
+        ElemStatus              m_status;
 };
 
 class ListData
@@ -196,16 +249,18 @@ class ListData
                 Colrec()
                 {
                     add( ptr );
-                    add( info );
                     add( icon );
+                    add( info );
+                    add( icon2 );
                 }
                 // HIDDEN COLUMNS
                 Gtk::TreeModelColumn< DiaryElement* >                   ptr;
                 // COLUMNS
-                Gtk::TreeModelColumn< Glib::ustring >                   info;
                 Gtk::TreeModelColumn< Glib::RefPtr< Gdk::Pixbuf > >     icon;
+                Gtk::TreeModelColumn< Glib::ustring >                   info;
+                Gtk::TreeModelColumn< Glib::RefPtr< Gdk::Pixbuf > >     icon2;
         };
-        static Colrec           *colrec;
+        static Colrec*          colrec;
 
         Gtk::TreePath           treepath;
 };
@@ -240,28 +295,28 @@ create_unique_name_for_map( const std::map< Glib::ustring, T*, FuncCompareString
 class ElementShowerProto
 {
     public:
-        ElementShowerProto( void ) : m_menu( NULL ) {}
+        ElementShowerProto() : m_menu( NULL ) {}
         virtual             ~ElementShowerProto() {}
 
-        virtual DiaryElement*   get_element( void ) = 0;
+        virtual DiaryElement*   get_element() = 0;
 
-        Gtk::Widget*            get_widget( void )
+        Gtk::Widget*            get_widget()
         { return m_vbox; }
-        virtual Menu2*          get_menu( void )
+        virtual Gtk::Menu*      get_menu()
         { return m_menu; }
-        virtual Gtk::Widget*    get_extra_tools( void )
+        virtual Gtk::Widget*    get_extra_tools()
         { return NULL; }
 
-        virtual Glib::ustring   get_title_str( void ) const
+        virtual Glib::ustring   get_title_str() const
         { return ""; }
-        virtual Glib::ustring   get_info_str( void ) const
+        virtual Glib::ustring   get_info_str() const
         { return ""; }
-        virtual Glib::ustring   get_tip_str( void ) const
+        virtual Glib::ustring   get_tip_str() const
         { return ""; }
 
-        virtual bool            is_title_editable( void ) const
+        virtual bool            is_title_editable() const
         { return false; }
-        virtual Glib::ustring   get_title_edit_str( void ) const
+        virtual Glib::ustring   get_title_edit_str() const
         { return get_title_str(); }
         virtual bool            check_title_applicable( const Glib::ustring& ) const
         { return false; }
@@ -269,8 +324,8 @@ class ElementShowerProto
         { return false; }
 
     protected:
-        Gtk::Box                *m_vbox;
-        Menu2                   *m_menu;
+        Gtk::Box*               m_vbox;
+        Gtk::Menu*              m_menu;
 };
 
 template< class T >
@@ -282,11 +337,11 @@ class ElementShower : public ElementShowerProto
         virtual void            show( T& ) = 0;
         virtual void            prepare_for_hiding( T& ) {}
 
-        T*                      get_element( void )
+        T*                      get_element()
         { return m_ptr2elem; }
 
     protected:
-        T                       *m_ptr2elem;
+        T*                      m_ptr2elem;
 };
 
 class DiaryElementContainer : public DiaryElement
@@ -294,278 +349,40 @@ class DiaryElementContainer : public DiaryElement
 // NOTE: this class and its derivatives are not responsible for handling of...
 // ...its children's allocation and deletion
     public:
-        DiaryElementContainer( DiaryBase * const d )
-        :   DiaryElement( d, "" ), m_items( compare_listitems ) {}
-        DiaryElementContainer( DiaryBase * const d, const Glib::ustring &name )
-        :   DiaryElement( d, name ), m_items( compare_listitems ) {}
+        DiaryElementContainer( DiaryBase* const d )
+        :   DiaryElement( d, ES::VOID ), m_items( compare_listitems ) {}
+        DiaryElementContainer( DiaryBase* const d, const Glib::ustring &name )
+        :   DiaryElement( d, ES::VOID, name ), m_items( compare_listitems ) {}
 
-        SetDiaryElements*       get_items( void )
+        SetDiaryElements*       get_items()
         { return &m_items; }
-        virtual int             get_size( void ) const
+        virtual int             get_size() const
         { return m_items.size(); }
 
-        void                    clear( void )
+        void                    clear()
         { m_items.clear(); }
 
     protected:
         SetDiaryElements        m_items;
 };
 
-// TAG =============================================================================================
-class Tag;	// forward declaration
-
-// TAG CATEGORY
-// TODO: should be a DiaryElementContainer as it is not responsible for memory handling
-class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiaryElemNamed >
+// THEME ===========================================================================================
+class Theme
 {
     public:
-        static ElementShower< CategoryTags > *shower;
-
-                                CategoryTags( DiaryBase * const, const Glib::ustring& );
-
-        void                    show( void );
-
-        virtual int             get_size( void ) const
-        { return size(); }
-        Type                    get_type( void ) const
-        { return ET_TAG_CTG; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon( void ) const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32( void ) const;
-
-        Glib::ustring           get_list_str( void ) const
-        { return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) ); }
-
-        bool                    get_expanded( void ) const
-        { return m_flag_expanded; }
-        void                    set_expanded( bool flag_expanded )
-        { m_flag_expanded = flag_expanded; }
-
-    protected:
-        bool                    m_flag_expanded;
-
-    friend class CategoryTagsView;
-    friend class PoolCategoriesTags;
-    friend class PanelExtra;
-};
-
-// POOL OF DEFINED TAG CATEGORIES
-class PoolCategoriesTags : public std::map< Glib::ustring, CategoryTags*, FuncCompareStrings >
-{
-    public:
-                                PoolCategoriesTags( void );
-                                ~PoolCategoriesTags();
-
-        bool                    rename_category( CategoryTags*, const Glib::ustring& );
-        void                    clear( void );
-};
-
-// TAG
-class Tag : public DiaryElementContainer
-{
-    public:
-        static ElementShower< Tag > *shower;
-
-                                Tag( DiaryBase * const d )
-                                :   DiaryElementContainer( d ),
-                                    m_ptr2category( NULL ) {}
-        explicit                Tag( DiaryBase * const, const Glib::ustring&, CategoryTags* );
-        virtual                 ~Tag( void );
-
-        void                    show( void );
-
-        CategoryTags*           get_category( void )
-        { return m_ptr2category; }
-        void                    set_category( CategoryTags *category );
-
-        void                    set_name( const Glib::ustring& );
-        //Date                  get_date( void ) const; // if earliest entry's date is needed
-        Type                    get_type( void ) const
-        { return ET_TAG; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon( void ) const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32( void ) const;
-
-        Glib::ustring           get_list_str( void ) const
-        { return Glib::Markup::escape_text( m_name ); }
-
-    protected:
-        CategoryTags            *m_ptr2category;
-
-    friend class PoolTags;
-    friend class Tagset;
-    friend class TagView;
-};
-
-// POOL OF DEFINED TAGS
-class PoolTags : public std::map< Glib::ustring, Tag*, FuncCompareStrings >
-{
-    public:
-                                PoolTags( void )
-        :   std::map< Glib::ustring, Tag*, FuncCompareStrings >( compare_names ) {}
-                                ~PoolTags();
-
-        bool                    handle_tag_changed( );
-        bool                    rename( Tag*, const Glib::ustring& );
-        Tag*                    get_tag( unsigned int );
-        Tag*                    get_tag( const Glib::ustring& );
-        void                    clear( void );
-};
-
-// TAGS OF AN ENTRY
-// not responsible for memory handling
-class Tagset : public std::set< Tag*, FuncCompareDiaryElemNamed >
-{
-    public:
-                                Tagset( void )
-        :   std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name ) {}
-
-                                ~Tagset( void );
-        bool                    add( Tag* );
-        bool                    checkfor_member( const Tag* ) const;
-        const Tag*              get_tag( unsigned int ) const;
-        //bool                  remove_tag( const Glib::ustring& );
-
-    protected:
-
-};
-
-// CHAPTER =========================================================================================
-class Chapter : public DiaryElement
-{
-    public:
-        static ElementShower< Chapter > *shower;
-
-        explicit                Chapter( DiaryBase * const, const Glib::ustring& );
-                                Chapter( DiaryBase * const, const Glib::ustring&, Date );
-        // this class should have a virtual dtor for some reason because
-        // if it does not, its derived classes cannot be deleted
-        virtual                 ~Chapter() {}
-
-        void                    show( void );
-
-        void                    set_name( const Glib::ustring& );
-        Date                    get_date( void ) const;
-        Glib::ustring           get_date_str( void ) const;
-        void                    set_date( Date::date_t );
-        virtual int             get_size( void ) const  // TODO: stub!
-        { return m_size; }
-        Type                    get_type( void ) const
-        { return ET_CHAPTER; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon( void ) const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                get_icon32( void ) const;
-
-        Date                    get_free_order( void ) const;
-
-        Glib::ustring           get_list_str( void ) const
-        { return Glib::ustring::compose( "<b>%1 -  %2</b>", m_date_begin.format_string(),
-                Glib::Markup::escape_text( m_name ) ); }
-
-        bool                    get_expanded( void ) const
-        { return m_flag_expanded; }
-        void                    set_expanded( bool flag_expanded )
-        { m_flag_expanded = flag_expanded; }
-
-        bool                    is_initialized( void ) const
-        { return( m_date_begin.m_date != Date::NOTSET ); }
-        bool                    is_ordinal( void ) const
-        { return m_date_begin.is_ordinal(); }
-
-        void                    reset_size( void )
-        { m_size = 0; }
-        void                    increase_size()
-        { m_size++; }
-        void                    recalculate_span( const Chapter* );
-
-    protected:
-        Date                    m_date_begin;
-        int                     m_time_span;
-        int                     m_size;
-        bool                    m_flag_expanded;
-
-    friend class CategoryChapters;
-    friend class ChapterView;
-};
-
-class CategoryChapters :
-        public DiaryElement, public std::map< Date::date_t, Chapter*, FuncCompareDates >
-{
-    public:
-        explicit                CategoryChapters( DiaryBase * const d, const Glib::ustring& );
-        virtual                 ~CategoryChapters();
-
-        virtual int             get_size( void ) const
-        { return size(); }
-        Type                    get_type( void ) const
-        { return ET_CHAPTER_CTG; }
-
-        void                    show( void ) {} // not used
-
-        Chapter*                get_chapter( const Date::date_t ) const;
-
-        Chapter*                create_chapter( const Glib::ustring&, const Date& );
-        void                    dismiss_chapter( Chapter* );
-        bool                    rename_chapter( Chapter*, const Glib::ustring& );
-        bool                    set_chapter_date( Chapter*, Date::date_t );
-
-        bool                    add( Chapter* );
-
-        void                    clear( void );
-
-        Date                    get_free_order_ordinal( void ) const;
-
-    protected:
-
-};
-
-class PoolCategoriesChapters :
-        public std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >
-{
-    public:
-                                    PoolCategoriesChapters( void )
-        :   std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >(
-                compare_names ) {}
-                                    ~PoolCategoriesChapters();
-        void                        clear( void );
-};
-
-// THEMES ==========================================================================================
-class Theme : public DiaryElement
-{
-    public:
-        static ElementShower< Theme > *shower;
-
-                                    Theme( DiaryBase * const, const Glib::ustring& );
-                                    Theme( DiaryBase * const,
-                                           const Glib::ustring&,
-                                           const Glib::ustring&,
+                                    Theme();
+                                    Theme( const Glib::ustring&,
                                            const std::string&,
                                            const std::string&,
                                            const std::string&,
                                            const std::string&,
                                            const std::string& );
         // duplicates an existing theme, works like a copy constructor
-                                    Theme( DiaryBase * const, const Theme*, const Glib::ustring& );
+                                    Theme( const Theme* );
+        virtual                     ~Theme() {}
 
-        void                        show( void );
 
-        int                         get_size( void ) const
-        { return 0; }   // redundant
-        DiaryElement::Type          get_type( void ) const
-        { return ET_THEME; }
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                    get_icon( void ) const;
-        const Glib::RefPtr< Gdk::Pixbuf >&
-                                    get_icon32( void ) const;
-
-        Glib::ustring               get_list_str( void ) const
-        { return Glib::Markup::escape_text( m_name ); }
-
-        virtual bool                is_system( void ) const
+        virtual bool                is_system() const
         { return false; }
 
         Pango::FontDescription      font;
@@ -582,15 +399,13 @@ class Theme : public DiaryElement
         static const Gdk::RGBA      s_color_link2;
         static const Gdk::RGBA      s_color_broken;
         static const Gdk::RGBA      s_color_broken2;
-
-    friend class Diary;
 };
 
 class ThemeSystem : public Theme
 {
     public:
-        static ThemeSystem*         get( void );
-        bool                        is_system( void ) const
+        static ThemeSystem*         get();
+        bool                        is_system() const
         { return true; }
 
     protected:
@@ -602,15 +417,338 @@ class ThemeSystem : public Theme
                                                  const std::string& );
 };
 
-class PoolThemes : public std::map< Glib::ustring, Theme*, FuncCompareStrings >
+// TAG =============================================================================================
+class Tag;	// forward declaration
+
+// TAG CATEGORY
+// TODO: should be a DiaryElementContainer as it is not responsible for memory handling
+class CategoryTags : public DiaryElement, public std::set< Tag*, FuncCompareDiaryElemNamed >
 {
     public:
-                                    PoolThemes( void )
-        :   std::map< Glib::ustring, Theme*, FuncCompareStrings >( compare_names ) {}
-                                    ~PoolThemes();
+        static ElementShower< CategoryTags >* shower;
 
-        void                        clear( void );
-        bool                        rename_theme( Theme*, const Glib::ustring& );
+                                CategoryTags( DiaryBase * const, const Glib::ustring& );
+
+        void                    show();
+
+        virtual int             get_size() const
+        { return size(); }
+        Type                    get_type() const
+        { return ET_TAG_CTG; }
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon() const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32() const;
+
+        Glib::ustring           get_list_str() const
+        { return Glib::ustring::compose( "<b>%1</b>", Glib::Markup::escape_text( m_name ) ); }
+
+        bool                    get_expanded() const
+        { return( m_status & ES::EXPANDED ); }
+        void                    set_expanded( bool flag_expanded )
+        {
+            if( flag_expanded )
+                m_status |= ES::EXPANDED;
+            else if( m_status & ES::EXPANDED )
+                m_status -= ES::EXPANDED;
+        }
+
+    protected:
+
+    friend class CategoryTagsView;
+    friend class PoolCategoriesTags;
+    friend class PanelExtra;
+};
+
+// POOL OF DEFINED TAG CATEGORIES
+class PoolCategoriesTags : public std::map< Glib::ustring, CategoryTags*, FuncCompareStrings >
+{
+    public:
+                                PoolCategoriesTags();
+                                ~PoolCategoriesTags();
+
+        bool                    rename_category( CategoryTags*, const Glib::ustring& );
+        void                    clear();
+};
+
+// TAG
+class Tag : public DiaryElementContainer
+{
+    public:
+        static ElementShower< Tag > *shower;
+
+                                Tag( DiaryBase* const d )
+                                :   DiaryElementContainer( d ),
+                                    m_ptr2category( NULL ), m_theme( NULL ) {}
+        explicit                Tag( DiaryBase* const, const Glib::ustring&, CategoryTags* );
+        virtual                 ~Tag();
+
+        void                    show();
+
+        CategoryTags*           get_category()
+        { return m_ptr2category; }
+        void                    set_category( CategoryTags* );
+
+        Theme*                  get_theme() const;
+        bool                    get_has_own_theme() const
+        { return( m_theme != NULL ); }
+        Theme*                  get_own_theme();
+        Theme*                  create_own_theme_duplicating( const Theme* );
+        void                    reset_theme();
+
+        void                    set_name( const Glib::ustring& );
+        //Date                  get_date() const; // if earliest entry's date is needed
+        virtual Type            get_type() const
+        { return ET_TAG; }
+        virtual const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon() const;
+        virtual const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32() const;
+
+        virtual Glib::ustring   get_list_str() const
+        { return Glib::Markup::escape_text( m_name ); }
+
+    protected:
+        CategoryTags*           m_ptr2category;
+        Theme*                  m_theme;
+
+    friend class PoolTags;
+    friend class Tagset;
+};
+
+class Untagged : public Tag
+{
+    public:
+                                Untagged();
+
+        Type                    get_type() const
+        { return ET_UNTAGGED; }
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon() const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32() const;
+        /*const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon() const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32() const;*/
+
+        Glib::ustring           get_list_str() const;
+};
+
+// POOL OF DEFINED TAGS
+class PoolTags : public std::map< Glib::ustring, Tag*, FuncCompareStrings >
+{
+    public:
+                                PoolTags()
+        :   std::map< Glib::ustring, Tag*, FuncCompareStrings >( compare_names ) {}
+                                ~PoolTags();
+
+        bool                    handle_tag_changed( );
+        bool                    rename( Tag*, const Glib::ustring& );
+        Tag*                    get_tag( unsigned int );
+        Tag*                    get_tag( const Glib::ustring& );
+        void                    clear();
+};
+
+// TAGS OF AN ENTRY
+// not responsible for memory handling
+class Tagset : public std::set< Tag*, FuncCompareDiaryElemNamed >
+{
+    public:
+                                Tagset()
+        :   std::set< Tag*, FuncCompareDiaryElemNamed >( compare_listitems_by_name ) {}
+
+                                ~Tagset();
+        bool                    add( Tag* );
+        bool                    checkfor_member( const Tag* ) const;
+        const Tag*              get_tag( unsigned int ) const;
+        //bool                  remove_tag( const Glib::ustring& );
+
+    protected:
+
+};
+
+// CHAPTER =========================================================================================
+class Chapter : public DiaryElement
+{
+    public:
+        static ElementShower< Chapter >* shower;
+
+        explicit                Chapter( DiaryBase* const, const Glib::ustring& );
+                                Chapter( DiaryBase* const, const Glib::ustring&, Date );
+        // this class should have a virtual dtor for some reason because
+        // if it does not, its derived classes cannot be deleted
+        virtual                 ~Chapter() {}
+
+        void                    show();
+
+        void                    set_name( const Glib::ustring& );
+        Date                    get_date() const;
+        Glib::ustring           get_date_str() const;
+        void                    set_date( Date::date_t date )
+        { m_date_begin.m_date = date; update_type(); }
+        virtual int             get_size() const  // TODO: stub!
+        { return m_size; }
+        Type                    get_type() const
+        { return m_type; }
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon() const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                get_icon32() const;
+
+        Date                    get_free_order() const;
+
+        Glib::ustring           get_list_str() const
+        { return Glib::ustring::compose( "<b>%1 -  %2</b>", m_date_begin.format_string(),
+                Glib::Markup::escape_text( m_name ) ); }
+
+        bool                    get_expanded() const
+        { return( m_status & ES::EXPANDED ); }
+        void                    set_expanded( bool flag_expanded )
+        {
+            if( flag_expanded )
+                m_status |= ES::EXPANDED;
+            else if( m_status & ES::EXPANDED )
+                m_status -= ES::EXPANDED;
+        }
+
+        bool                    is_initialized() const
+        { return( m_date_begin.m_date != Date::NOTSET ); }
+        bool                    is_ordinal() const
+        { return m_date_begin.is_ordinal(); }
+
+        void                    reset_size()
+        { m_size = 0; }
+        void                    increase_size()
+        { m_size++; }
+        void                    recalculate_span( const Chapter* );
+
+        // only for to-do groups:
+        ElemStatus              get_todo_status() const
+        { return( m_status & ES::FILTER_TODO ); }
+        void                    set_todo_status( ElemStatus s )
+        {
+            m_status -= ( m_status & ES::FILTER_TODO );
+            m_status |= s;
+        }
+
+        void                    update_type();
+
+    protected:
+        Date                    m_date_begin;
+        int                     m_time_span;
+        int                     m_size;
+        Type                    m_type;
+
+    friend class CategoryChapters;
+    friend class ChapterView;
+};
+
+class CategoryChapters :
+        public DiaryElement, public std::map< Date::date_t, Chapter*, FuncCompareDates >
+{
+    public:
+        explicit                CategoryChapters( DiaryBase * const d, const Glib::ustring& );
+        virtual                 ~CategoryChapters();
+
+        virtual int             get_size() const
+        { return size(); }
+        Type                    get_type() const
+        { return ET_CHAPTER_CTG; }
+
+        void                    show() {} // not used
+
+        Chapter*                get_chapter( const Date::date_t ) const;
+
+        Chapter*                create_chapter( const Glib::ustring&, const Date& );
+        void                    dismiss_chapter( Chapter* );
+        bool                    rename_chapter( Chapter*, const Glib::ustring& );
+        bool                    set_chapter_date( Chapter*, Date::date_t );
+
+        bool                    add( Chapter* );
+
+        void                    clear();
+
+        Date                    get_free_order() const;
+
+    protected:
+
+};
+
+class PoolCategoriesChapters :
+        public std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >
+{
+    public:
+                                    PoolCategoriesChapters()
+        :   std::map< Glib::ustring, CategoryChapters*, FuncCompareStrings >(
+                compare_names ) {}
+                                    ~PoolCategoriesChapters();
+        void                        clear();
+};
+
+// FILTERS =========================================================================================
+class Filter : public DiaryElement
+{
+    public:
+        static ElementShower< Filter >* shower;
+
+                                    Filter( DiaryBase* const, const Glib::ustring& );
+
+        void                        show();
+
+        int                         get_size() const
+        { return 0; }   // redundant
+        DiaryElement::Type          get_type() const
+        { return ET_FILTER; }
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                    get_icon() const;
+        const Glib::RefPtr< Gdk::Pixbuf >&
+                                    get_icon32() const;
+
+        Glib::ustring               get_list_str() const
+        { return Glib::Markup::escape_text( m_name ); }
+
+        void                        reset();
+        void                        set( const Filter* );
+
+        const Tag*                  get_tag() const
+        {
+            return m_tag;
+        }
+        void                        set_tag( const Tag* );
+
+        void                        set_favorites( bool, bool );
+        void                        set_trash( bool, bool );
+        void                        set_todo( bool, bool, bool );
+
+        Date::date_t                get_date_begin() const
+        { return m_date_begin; }
+        Date::date_t                get_date_end() const
+        { return m_date_end; }
+        void                        set_date_begin( Date::date_t d );
+        void                        set_date_end( Date::date_t d );
+        void                        clear_dates();
+
+        void                        set_status_applied()
+        { if( m_status & ES::FILTER_OUTSTANDING ) m_status -= ES::FILTER_OUTSTANDING; }
+
+        void                        set_status_outstanding()
+        { m_status |= ES::FILTER_OUTSTANDING; }
+
+        const EntrySet*             get_entries() const
+        {
+            return &m_entries;
+        }
+        void                        add_entry( Entry* );
+        void                        remove_entry( Entry* );
+        void                        clear_entries();
+        bool                        is_entry_filtered( Entry* ) const;
+
+    protected:
+        const Tag*                  m_tag;
+        Date::date_t                m_date_begin;
+        Date::date_t                m_date_end;
+        EntrySet                    m_entries;
 };
 
 } // end of namespace LIFEO
