@@ -42,6 +42,8 @@ Error::Error( const Glib::ustring &error_message )
 }
 
 // DATE ============================================================================================
+std::string Date::s_date_format_template = "%1.%2.%3";
+
 Date::Date( const Glib::ustring &str_date )
 :   m_date( 0 )
 {
@@ -75,7 +77,7 @@ Date::Date( const Glib::ustring &str_date )
 //}
 
 Glib::Date::Month
-Date::get_month_glib( void ) const
+Date::get_month_glib() const
 {
     switch( ( m_date & 0x78000 ) >> 15 )
     {
@@ -108,29 +110,28 @@ Date::get_month_glib( void ) const
     }
 }
 
-// TODO: make date string format user configurable
 Glib::ustring
-Date::format_string( void ) const
+Date::format_string( const date_t d, const std::string &format )
 {
-    if( m_date & ORDINAL_FLAG )
+    if( d & ORDINAL_FLAG )
     {
-        return Glib::ustring::compose( get_order() ? "%1.%2" : "%1",
-                get_ordinal_order() + 1, get_order() );
+        return Glib::ustring::compose( get_order( d ) ? "%1.%2" : "%1",
+                get_ordinal_order( d ) + 1, get_order( d ) );
     }
     else
     {
-        return Glib::ustring::compose( "%1.%2.%3",
-                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_year() ),
-                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_month() ),
-                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_day() ) );
+        return Glib::ustring::compose( format,
+                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_year( d ) ),
+                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_month( d ) ),
+                Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), get_day( d ) ) );
     }
 }
 
 Glib::ustring
-Date::format_string( const time_t time )
+Date::format_string_dt( const time_t time )
 {
     struct tm *timeinfo = localtime( &time );
-    return Glib::ustring::compose( "%1.%2.%3, %4:%5",
+    return Glib::ustring::compose( s_date_format_template + ", %4:%5",
             1900 + timeinfo->tm_year,
             Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
             Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mday ),
@@ -140,29 +141,29 @@ Date::format_string( const time_t time )
 
 // date only
 Glib::ustring
-Date::format_string_do( const time_t time )
+Date::format_string_d( const time_t time )
 {
     struct tm *timeinfo = localtime( &time );
-    return Glib::ustring::compose( "%1.%2.%3",
+    return Glib::ustring::compose( s_date_format_template,
             1900 + timeinfo->tm_year,
             Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mon + 1 ),
             Glib::ustring::format( std::setfill( L'0' ), std::setw( 2 ), timeinfo->tm_mday ) );
 }
 
 Glib::ustring
-Date::get_year_str( void ) const
+Date::get_year_str() const
 {
     return Glib::ustring::compose( "%1", get_year() );
 }
 
 Glib::ustring
-Date::get_month_str( void ) const
+Date::get_month_str() const
 {
     return Glib::Date( 20, get_month_glib(), 2000 ).format_string( "%b" );
 }
 
 Glib::ustring
-Date::get_weekday_str( void ) const
+Date::get_weekday_str() const
 {
     // from wikipedia: http://en.wikipedia.org/wiki/Calculating_the_day_of_the_week
     const unsigned int year = get_year();
@@ -187,7 +188,7 @@ Date::get_weekday_str( void ) const
 }
 
 unsigned int
-Date::get_days_in_month( void ) const
+Date::get_days_in_month() const
 {
     switch( get_month() )
     {
@@ -200,12 +201,6 @@ Date::get_days_in_month( void ) const
     return 31;
 }
 
-time_t
-Date::get_ctime( void ) const
-{
-    return( get_ctime( m_date ) );
-}
-
 time_t
 Date::get_ctime( const Date::date_t d )
 {
@@ -241,7 +236,7 @@ Date::forward_months( int months )
 }
 
 void
-Date::forward_month( void )
+Date::forward_month()
 {
     int months = get_month() + 1;
     m_date &= 0x7FF80000;   // isolate year
@@ -259,7 +254,7 @@ Date::forward_month( void )
 }
 
 void
-Date::forward_day( void )
+Date::forward_day()
 {
     int day = get_day();
     if( day >= Glib::Date::get_days_in_month( get_month_glib(), get_year() ) )
@@ -449,19 +444,47 @@ get_file_size( std::ifstream &file )
    return size;
 }
 
-// URL HANDLERS
-void
-open_url( Gtk::AboutDialog&, const Glib::ustring &link )
+// FILE I/O
+bool
+copy_file_suffix( const std::string& source_path, const std::string& suffix1, int suffix2 )
 {
-    std::string command( "x-www-browser " );
-    command += link;
-    std::cout << "opening url: " << system( command.c_str() ) << std::endl;
-    // TODO: find a better way
+    try
+    {
+        Glib::RefPtr< Gio::File > file_src = Gio::File::create_for_path( source_path );
+        if( file_src )
+        {
+            std::stringstream ss;
+            ss << source_path << suffix1;
+            if( suffix2 >= 0 )
+                ss << suffix2;
+            int index( 0 );
+
+            while( Glib::file_test( ss.str(), Glib::FILE_TEST_EXISTS ) )
+            {
+                ss.str( std::string() );
+                ss.clear();
+                ss << source_path << suffix1;
+                if( suffix2 >= 0 )
+                    ss << suffix2;
+                ss << " (" << ++index << ")";
+            }
+
+            Glib::RefPtr< Gio::File > file_dest = Gio::File::create_for_path( ss.str() );
+
+            file_src->copy( file_dest );
+        }
+    }
+    catch( ... )
+    {
+        return false;
+    }
+
+    return true;
 }
 
 // ENVIRONMENT VARIABLES
 std::string
-get_env_lang( void )
+get_env_lang()
 {
     static std::string s_lang_env( "" );
     if( s_lang_env.empty() )
@@ -477,7 +500,7 @@ get_env_lang( void )
 
 // ENCRYPTION
 bool
-Cipher::init( void )
+Cipher::init()
 {
     // http://www.gnupg.org/documentation/manuals/gcrypt/Initializing-the-library.html
 
@@ -703,7 +726,7 @@ create_menuitem_markup( const Glib::ustring &str_markup,
     return menuitem;
 }
 
-// ENTRYIDLETEXT ===================================================================================
+// ENTRYCLEAR ======================================================================================
 EntryClear::EntryClear( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& )
     :   Gtk::Entry( cobject )
 {
@@ -718,7 +741,7 @@ EntryClear::handle_clear_icon( Gtk::EntryIconPosition icon_pos, const GdkEventBu
 }
 
 void
-EntryClear::on_changed( void )
+EntryClear::on_changed()
 {
     if( get_text().empty() )
     {
@@ -754,6 +777,8 @@ EntryClear::on_key_release_event( GdkEventKey *event )
 }
 
 // MENUBUTTON ======================================================================================
+#if( GTKMM_MAJOR_VERSION < 3 )
+
 Glib::ustring       Menubutton::s_builder_name;
 
 Menubutton::Menubutton( const Gtk::StockID &stockid,
@@ -845,13 +870,13 @@ Menubutton::Menubutton( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
     add_events( Gdk::BUTTON_PRESS_MASK );
 }
 
-Menubutton::~Menubutton( void )
+Menubutton::~Menubutton()
 {
     delete m_menu;
 }
 
 Menu2*
-Menubutton::get_menu( void ) const
+Menubutton::get_menu() const
 {
     return m_menu;
 }
@@ -881,7 +906,7 @@ Menubutton::set_menu( Menu2 *menu )
 }
 
 bool
-Menubutton::clear_menu( void )
+Menubutton::clear_menu()
 {
     if( m_menu->get_children().size() > 0 )
     {
@@ -898,7 +923,7 @@ Menubutton::clear_menu( void )
 }
 
 void
-Menubutton::release( void )
+Menubutton::release()
 {
     set_active( false );
 }
@@ -929,63 +954,10 @@ Menubutton::on_button_press_event( GdkEventButton *l_event )
     return true;
 }
 
-// MENUTOOLBUTTON
-/*
- * TO BE REWRITTEN IF NEEDED IN THE FUTURE...
-Menutoolbutton::Menutoolbutton( const Gtk::StockID& stockid,
-                                const std::string& string,
-                                Menu2 *menu,
-                                bool flag_important)
-:   m_flag_important( flag_important ),
-    m_button( stockid, string, Gtk::RELIEF_NONE, Gtk::ICON_SIZE_LARGE_TOOLBAR, menu )
-{
-    add( m_button );
-    m_button.m_icon->show();
-    m_button.m_label->show();
-}
-
-Menu2*
-Menutoolbutton::get_menu (void)
-{
-    return m_button.m_menu;
-}
-
-void
-Menutoolbutton::on_toolbar_reconfigured (void)
-{
-    if( m_button.m_label->get_parent() )
-        m_button.m_label->get_parent()->remove( *m_button.m_label );
-
-    if( m_button.m_icon->get_parent() )
-        m_button.m_icon->get_parent()->remove( *m_button.m_icon );
-
-    switch( get_toolbar_style() )
-    {
-        case Gtk::TOOLBAR_BOTH:
-            m_button.m_vbox->pack_start( *m_button.m_icon );
-            m_button.m_vbox->pack_start( *m_button.m_label );
-        break;
-        case Gtk::TOOLBAR_BOTH_HORIZ:
-            m_button.m_vbox->pack_start( *m_button.m_icon );
-            if( m_flag_important )
-            {
-                m_button.m_hbox->pack_start( *m_button.m_label );
-                m_button.m_hbox->reorder_child( *m_button.m_label, 1 );
-            }
-        break;
-        case Gtk::TOOLBAR_ICONS:
-            m_button.m_vbox->pack_start( *m_button.m_icon );
-        break;
-        case Gtk::TOOLBAR_TEXT:
-            m_button.m_vbox->pack_start( *m_button.m_label );
-        break;
-        default:
-        break;
-    }
-}
-*/
+#endif
 
 // MENUITEMRECENT ==================================================================================
+#if( GTKMM_MAJOR_VERSION < 3 ) // to be ported to gtkmm3 if needed
 MenuitemRecent::MenuitemRecent( const std::string &path )
 :   Gtk::MenuItem(), m_icon_remove( Gtk::Stock::DELETE, Gtk::ICON_SIZE_MENU ),
     m_path( path ), m_flag_deletepressed( false )
@@ -1057,9 +1029,7 @@ MenuitemRecent::on_button_release_event( GdkEventButton *event )
     return Gtk::MenuItem::on_button_release_event( event );
 }
 
-
 // FILEBUTTONRECENT ================================================================================
-#if( GTKMM_MAJOR_VERSION < 3 ) // to be ported to gtkmm3 if needed
 Glib::ustring   FilebuttonRecent::fallback_label = _( "Select or Create a Diary" );
 
 /*
@@ -1135,7 +1105,7 @@ FilebuttonRecent::set( ListPaths *list_recent )
 }
 
 std::string
-FilebuttonRecent::get_filename( void ) const
+FilebuttonRecent::get_filename() const
 {
     return( * m_list_recent->begin() );
 }
@@ -1257,7 +1227,7 @@ FilebuttonRecent::remove_recent( const std::string &path )
 }
 
 void
-FilebuttonRecent::show_filechooser( void )
+FilebuttonRecent::show_filechooser()
 {
     m_filechooserdialog = new Gtk::FileChooserDialog(
             _( "Select a Diary" ), Gtk::FILE_CHOOSER_ACTION_OPEN );
@@ -1284,7 +1254,7 @@ FilebuttonRecent::show_filechooser( void )
 }
 
 void
-FilebuttonRecent::on_create_file( void )
+FilebuttonRecent::on_create_file()
 {
     m_signal_createfile.emit();
 }
@@ -1320,21 +1290,22 @@ FilebuttonRecent::on_size_allocate( Gtk::Allocation &allocation )
 }
 
 SignalVoid
-FilebuttonRecent::signal_selection_changed( void )
+FilebuttonRecent::signal_selection_changed()
 {
     return m_signal_selectionchanged;
 }
 
 SignalVoid
-FilebuttonRecent::signal_create_file( void )
+FilebuttonRecent::signal_create_file()
 {
     return m_signal_createfile;
 }
+
 #endif
 // DIALOGEVENT =====================================================================================
 // the rest of the DialogEvent needs to be defined within the user application
 void
-DialogEvent::handle_logout( void )
+DialogEvent::handle_logout()
 {
     hide();
 }
@@ -1358,4 +1329,39 @@ create_frame( const Glib::ustring& str_label, Gtk::Widget& content )
     return frame;
 }
 
+// TREEVIEW ========================================================================================
+bool treepath_is_less( const Gtk::TreePath& p, const Gtk::TreePath& pb )
+{
+    for( unsigned int i = 0; i < p.size(); i++ )
+    {
+        if( i >= pb.size() )
+            return false;
+
+        if( p[i] < pb[ i ] )
+            return true;
+
+        if( p[i] > pb[ i ] )
+            return false;
+    }
+
+    return false; // more or equal
+}
+
+bool treepath_is_more( const Gtk::TreePath& p, const Gtk::TreePath& pe )
+{
+    for( unsigned int i = 0; i < p.size(); i++ )
+    {
+        if( i >= pe.size() )
+            return true;
+
+        if( p[i] > pe[ i ] )
+            return true;
+
+        if( p[i] < pe[ i ] )
+            return false;
+    }
+
+    return false; // less or equal
+}
+
 } // end of name space
