@@ -411,6 +411,25 @@ class Cipher
 
 };
 
+struct CipherBuffers
+{
+    CipherBuffers()
+    :   buffer( NULL ), salt( NULL ), iv( NULL ), key( NULL ) {}
+
+    unsigned char* buffer;
+    unsigned char* salt;
+    unsigned char* iv;
+    unsigned char* key;
+
+    void clear()
+    {
+        if( buffer ) delete[] buffer;
+        if( salt ) delete[] salt;
+        if( iv ) delete[] iv;
+        if( key ) delete[] key;
+    }
+};
+
 // ENTRY WIDGET WITH SELF-HANDLED CLEAR ICON =======================================================
 class EntryClear : public Gtk::Entry
 {
