@@ -51,6 +51,14 @@ PanelDiary::PanelDiary()
         Lifeograph::builder->get_widget( "menuitem_sort_by_size", m_menuitem_sort_by_size );
         Lifeograph::builder->get_widget( "menuitem_sort_by_change", m_menuitem_sort_by_change );
 
+        Lifeograph::builder->get_widget_derived( "entry_search", m_entry_search );
+        Lifeograph::builder->get_widget_derived( "entry_replace", m_entry_replace );
+        Lifeograph::builder->get_widget( "button_match_prev", m_button_match_prev );
+        Lifeograph::builder->get_widget( "button_match_next", m_button_match_next );
+        Lifeograph::builder->get_widget( "grid_replace", m_grid_replace );
+        Lifeograph::builder->get_widget( "button_replace", m_button_replace );
+        Lifeograph::builder->get_widget( "button_replace_all", m_button_replace_all );
+
         // FALLBACK ICON FOR SYSTEMS WITHOUT SYMBOLIC ICONS
         Glib::RefPtr< Gtk::IconTheme > theme = Gtk::IconTheme::get_default();
         if( ! theme->has_icon( "preferences-system-symbolic" ) &&
@@ -116,6 +124,18 @@ PanelDiary::PanelDiary()
     m_menuitem_add_chapter->signal_activate().connect(
             sigc::mem_fun( this, &PanelDiary::handle_add_chapter ) );
 
+    m_entry_search->signal_changed().connect(
+            sigc::mem_fun( this, &PanelDiary::handle_search_string_changed ) );
+    m_entry_search->signal_activate().connect(
+            sigc::mem_fun( AppWindow::p->panel_diary, &PanelDiary::go_next_match ) );
+
+    m_entry_replace->signal_activate().connect(
+            sigc::mem_fun( this, &PanelDiary::replace_match ) );
+    m_button_replace->signal_clicked().connect(
+            sigc::mem_fun( this, &PanelDiary::replace_match ) );
+    m_button_replace_all->signal_clicked().connect(
+            sigc::mem_fun( this, &PanelDiary::replace_all_matches ) );
+
     // ACTIONS
     Lifeograph::create_action(
             true, m_action_today, "Today", "x-office-calendar", _( "Today" ),
@@ -154,6 +174,35 @@ PanelDiary::PanelDiary()
             GDK_KEY_Escape,
             Gdk::CONTROL_MASK,
             Gtk::ACCEL_VISIBLE );
+
+    // ACTIONS
+    Lifeograph::create_action(
+            false, m_action_focusfilter, "FocusFilter",
+            Gtk::Stock::FIND, "", "",     // no grachical interface yet!
+            Gtk::AccelKey( GDK_KEY_f, Gdk::CONTROL_MASK ),
+            sigc::mem_fun( m_entry_search, &Gtk::Widget::grab_focus ) );
+
+    Lifeograph::create_action(
+            false, m_action_previous_match, "MatchPrevious", Gtk::Stock::GO_BACK,
+// TRANSLATORS: label and tooltip of the go-to-previous-match-of-filtered-text action
+            _( "Previous Match" ),
+            _( "Go to previous match" ),
+            Gtk::AccelKey( GDK_KEY_F3, Gdk::SHIFT_MASK ),
+            sigc::mem_fun( this, &PanelDiary::go_prev_match ),
+            m_button_match_prev );
+
+    Lifeograph::create_action(
+            false, m_action_next_match, "MatchNext", Gtk::Stock::GO_FORWARD,
+// TRANSLATORS: label and tooltip of the go-to-next-match-of-filtered-text action
+            _( "Next Match" ),
+            _( "Go to next match" ),
+            Gtk::AccelKey( GDK_KEY_F3, Gdk::ModifierType( 0 ) ),
+            sigc::mem_fun( this, &PanelDiary::go_next_match ),
+            m_button_match_next );
+
+    // becoming proxy widgets makes them visible:
+    m_button_match_prev->set_visible( false );
+    m_button_match_next->set_visible( false );
 }
 
 void
@@ -417,6 +466,13 @@ PanelDiary::handle_logout()
 
     m_treeview_entries->clear();
 
+    m_entry_search->set_text( "" );
+    m_entry_replace->set_text( "" );
+
+    m_button_match_prev->hide();
+    m_button_match_next->hide();
+    m_grid_replace->hide();
+
     Lifeograph::m_internaloperation--;
 }
 
@@ -737,3 +793,82 @@ PanelDiary::handle_treeview_row_expanded( const Gtk::TreeIter& iter,
         break;
     }
 }
+
+// SEARCH & REPLACE
+void
+PanelDiary::handle_search_string_changed()
+{
+    if( Lifeograph::m_internaloperation ) return;
+    // current entry must be closed here or else it loses...
+    // ...changes since it was selected:
+    //AppWindow::p->m_entry_view->sync(); update_entry_list() does the syncing
+
+    const std::string filterstring( m_entry_search->get_text().lowercase() );
+
+    Diary::d->set_search_text( filterstring );
+    AppWindow::p->panel_diary->update_entry_list();    // syncs current entry
+
+    if( filterstring.size() > 0 )
+    {
+        if( AppWindow::p->panel_diary->get_entry_count() > 0 )
+        {
+            AppWindow::p->m_entry_view->get_buffer()->set_search_str( filterstring );
+            if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
+                AppWindow::p->m_entry_view->get_buffer()->select_searchstr_next();
+        }
+
+        m_entry_search->set_tooltip_markup(
+                Glib::ustring::compose(
+                        _( "Found in <b>%1</b> of <b>%2</b> entrie(s)" ),
+                        AppWindow::p->panel_diary->get_entry_count(), Diary::d->get_size() ) );
+    }
+    else
+    {
+        AppWindow::p->m_entry_view->get_buffer()->set_search_str( "" );
+        m_entry_search->set_tooltip_text( _( "Enter text to be filtered" ) );
+    }
+
+    AppWindow::p->panel_diary->update_calendar();
+
+    if( AppWindow::p->panel_diary->get_entry_count() < 1 || filterstring.size() < 1 )
+    {
+        m_button_match_prev->hide();
+        m_button_match_next->hide();
+        m_grid_replace->hide();
+    }
+    else
+    {
+        m_button_match_prev->show();
+        m_button_match_next->show();
+        if( ! Diary::d->is_read_only() )
+            m_grid_replace->show();
+    }
+}
+
+void
+PanelDiary::replace_match()
+{
+    if( ! AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
+        AppWindow::p->panel_diary->go_next_match();
+    if( AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
+    {
+        AppWindow::p->m_entry_view->get_buffer()->erase_selection();
+        AppWindow::p->m_entry_view->get_buffer()->insert_at_cursor( m_entry_replace->get_text() );
+        AppWindow::p->panel_diary->go_next_match();
+    }
+}
+
+void
+PanelDiary::replace_all_matches()
+{
+    AppWindow::p->m_entry_view->sync();
+
+    Diary::d->replace_text( m_entry_replace->get_text() );
+    // update current entry:
+    if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
+    {
+        Entry *entry = dynamic_cast< Entry* >( AppWindow::p->panel_main->get_cur_elem() );
+        AppWindow::p->m_entry_view->get_buffer()->set_richtext( entry );
+    }
+}
+
