@@ -75,22 +75,38 @@ class PanelDiary
         void                    handle_add_chapter();
 
         void                    fill_child_rows( const Gtk::TreeModel::Children& );
+        
+        void                    handle_search_string_changed();
+        void                    replace_match();
+        void                    replace_all_matches();
 
-        WidgetEntryList         *m_treeview_entries;
+        WidgetEntryList*        m_treeview_entries;
 
-        Gtk::Button             *m_button_logout;
-        Gtk::Calendar           *m_calendar;
+        Gtk::Button*            m_button_logout;
+        Gtk::Calendar*          m_calendar;
 
-        Gtk::RadioMenuItem      *m_menuitem_sort_by_date;
-        Gtk::RadioMenuItem      *m_menuitem_sort_by_size;
-        Gtk::RadioMenuItem      *m_menuitem_sort_by_change;
+        Gtk::RadioMenuItem*     m_menuitem_sort_by_date;
+        Gtk::RadioMenuItem*     m_menuitem_sort_by_size;
+        Gtk::RadioMenuItem*     m_menuitem_sort_by_change;
 
-        Gtk::MenuButton         *m_button_add;
-        Gtk::ImageMenuItem      *m_menuitem_add_entry;
-        Gtk::ImageMenuItem      *m_menuitem_add_topic;
-        Gtk::ImageMenuItem      *m_menuitem_add_todo_group;
-        Gtk::ImageMenuItem      *m_menuitem_add_chapter;
-        Gtk::Separator          *m_sprt_tb1;
+        Gtk::Grid*              m_grid_elem_header;
+        Gtk::ButtonBox*         m_buttonbox_new_item;
+        Gtk::MenuButton*        m_button_add;
+        Gtk::ImageMenuItem*     m_menuitem_add_entry;
+        Gtk::ImageMenuItem*     m_menuitem_add_topic;
+        Gtk::ImageMenuItem*     m_menuitem_add_todo_group;
+        Gtk::ImageMenuItem*     m_menuitem_add_chapter;
+        Gtk::Separator*         m_sprt_tb1;
+        
+        Gtk::MenuButton*        m_button_tools;
+
+        EntryClear*             m_entry_search;
+        EntryClear*             m_entry_replace;
+        Gtk::Button*            m_button_match_prev;
+        Gtk::Button*            m_button_match_next;
+        Gtk::Grid*              m_grid_replace;
+        Gtk::Button*            m_button_replace;
+        Gtk::Button*            m_button_replace_all;
 
         Glib::RefPtr< Gtk::Action > m_action_today;
         Glib::RefPtr< Gtk::Action > m_action_previous_list;
@@ -98,6 +114,10 @@ class PanelDiary
         Glib::RefPtr< Gtk::Action > m_action_jump2current;
         Glib::RefPtr< Gtk::Action > m_action_show_prev_session_elem;
 
+        Glib::RefPtr< Gtk::Action > m_action_focusfilter;
+        Glib::RefPtr< Gtk::Action > m_action_previous_match;
+        Glib::RefPtr< Gtk::Action > m_action_next_match;
+
         // LISTING TMP VARIABLES
         void                    add_chapter_category_to_list( const CategoryChapters* );
         EntryIter               l_itr_entry;
