@@ -74,14 +74,6 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
         column = Gtk::manage( new Gtk::TreeViewColumn( "" ) );
 
         Lifeograph::builder->get_widget( "button_filter", m_button_filter );
-
-        Lifeograph::builder->get_widget_derived( "entry_search", m_entry_search );
-        Lifeograph::builder->get_widget_derived( "entry_replace", m_entry_replace );
-        Lifeograph::builder->get_widget( "button_match_prev", m_button_match_prev );
-        Lifeograph::builder->get_widget( "button_match_next", m_button_match_next );
-        Lifeograph::builder->get_widget( "button_replace", m_button_replace );
-        Lifeograph::builder->get_widget( "button_replace_all", m_button_replace_all );
-        Lifeograph::builder->get_widget( "grid_replace", m_grid_replace );
     }
     catch( ... )
     {
@@ -134,46 +126,6 @@ PanelExtra::PanelExtra( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder
 
     m_button_filter->signal_clicked().connect(
             sigc::mem_fun( Diary::d->m_filter_active, &DiaryElement::show ) );
-    m_entry_search->signal_changed().connect(
-            sigc::mem_fun( this, &PanelExtra::handle_search_string_changed ) );
-    m_entry_search->signal_activate().connect(
-            sigc::mem_fun( AppWindow::p->panel_diary, &PanelDiary::go_next_match ) );
-
-    m_entry_replace->signal_activate().connect(
-            sigc::mem_fun( this, &PanelExtra::replace_match ) );
-    m_button_replace->signal_clicked().connect(
-            sigc::mem_fun( this, &PanelExtra::replace_match ) );
-    m_button_replace_all->signal_clicked().connect(
-            sigc::mem_fun( this, &PanelExtra::replace_all_matches ) );
-
-    // ACTIONS
-    Lifeograph::create_action(
-            false, m_action_focusfilter, "FocusFilter",
-            Gtk::Stock::FIND, "", "",     // no grachical interface yet!
-            Gtk::AccelKey( GDK_KEY_f, Gdk::CONTROL_MASK ),
-            sigc::mem_fun( m_entry_search, &Gtk::Widget::grab_focus ) );
-
-    Lifeograph::create_action(
-            false, m_action_previous_match, "MatchPrevious", Gtk::Stock::GO_BACK,
-// TRANSLATORS: label and tooltip of the go-to-previous-match-of-filtered-text action
-            _( "Previous Match" ),
-            _( "Go to previous match" ),
-            Gtk::AccelKey( GDK_KEY_F3, Gdk::SHIFT_MASK ),
-            sigc::mem_fun( AppWindow::p->panel_diary, &PanelDiary::go_prev_match ),
-            m_button_match_prev );
-
-    Lifeograph::create_action(
-            false, m_action_next_match, "MatchNext", Gtk::Stock::GO_FORWARD,
-// TRANSLATORS: label and tooltip of the go-to-next-match-of-filtered-text action
-            _( "Next Match" ),
-            _( "Go to next match" ),
-            Gtk::AccelKey( GDK_KEY_F3, Gdk::ModifierType( 0 ) ),
-            sigc::mem_fun( AppWindow::p->panel_diary, &PanelDiary::go_next_match ),
-            m_button_match_next );
-
-    // becoming proxy widgets makes them visible:
-    m_button_match_prev->set_visible( false );
-    m_button_match_next->set_visible( false );
 }
 
 void
@@ -200,13 +152,6 @@ PanelExtra::handle_logout()
 
     m_treestore_all_tags->clear();
 
-    m_entry_search->set_text( "" );
-    m_entry_replace->set_text( "" );
-
-    m_button_match_prev->hide();
-    m_button_match_next->hide();
-    m_grid_replace->hide();
-
     Lifeograph::m_internaloperation--;
 }
 
@@ -597,81 +542,3 @@ PanelExtra::handle_treeview_row_activated( const Gtk::TreePath& path, Gtk::TreeV
         AppWindow::p->panel_diary->update_entry_list();
     }
 }
-
-// FILTER & REPLACE
-void
-PanelExtra::handle_search_string_changed()
-{
-    if( Lifeograph::m_internaloperation ) return;
-    // current entry must be closed here or else it loses...
-    // ...changes since it was selected:
-    //AppWindow::p->m_entry_view->sync(); update_entry_list() does the syncing
-
-    const std::string filterstring( m_entry_search->get_text().lowercase() );
-
-    Diary::d->set_search_text( filterstring );
-    AppWindow::p->panel_diary->update_entry_list();    // syncs current entry
-
-    if( filterstring.size() > 0 )
-    {
-        if( AppWindow::p->panel_diary->get_entry_count() > 0 )
-        {
-            AppWindow::p->m_entry_view->get_buffer()->set_search_str( filterstring );
-            if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
-                AppWindow::p->m_entry_view->get_buffer()->select_searchstr_next();
-        }
-
-        m_entry_search->set_tooltip_markup(
-                Glib::ustring::compose(
-                        _( "Found in <b>%1</b> of <b>%2</b> entrie(s)" ),
-                        AppWindow::p->panel_diary->get_entry_count(), Diary::d->get_size() ) );
-    }
-    else
-    {
-        AppWindow::p->m_entry_view->get_buffer()->set_search_str( "" );
-        m_entry_search->set_tooltip_text( _( "Enter text to be filtered" ) );
-    }
-
-    AppWindow::p->panel_diary->update_calendar();
-
-    if( AppWindow::p->panel_diary->get_entry_count() < 1 || filterstring.size() < 1 )
-    {
-        m_button_match_prev->hide();
-        m_button_match_next->hide();
-        m_grid_replace->hide();
-    }
-    else
-    {
-        m_button_match_prev->show();
-        m_button_match_next->show();
-        if( ! Diary::d->is_read_only() )
-            m_grid_replace->show();
-    }
-}
-
-void
-PanelExtra::replace_match()
-{
-    if( ! AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
-        AppWindow::p->panel_diary->go_next_match();
-    if( AppWindow::p->m_entry_view->get_buffer()->get_has_selection() )
-    {
-        AppWindow::p->m_entry_view->get_buffer()->erase_selection();
-        AppWindow::p->m_entry_view->get_buffer()->insert_at_cursor( m_entry_replace->get_text() );
-        AppWindow::p->panel_diary->go_next_match();
-    }
-}
-
-void
-PanelExtra::replace_all_matches()
-{
-    AppWindow::p->m_entry_view->sync();
-
-    Diary::d->replace_text( m_entry_replace->get_text() );
-    // update current entry:
-    if( AppWindow::p->panel_main->get_cur_elem_type() == DiaryElement::ET_ENTRY )
-    {
-        Entry *entry = dynamic_cast< Entry* >( AppWindow::p->panel_main->get_cur_elem() );
-        AppWindow::p->m_entry_view->get_buffer()->set_richtext( entry );
-    }
-}
