@@ -28,7 +28,7 @@
 using namespace LIFEO;
 
 
-PanelMain::PanelMain( void )
+PanelMain::PanelMain()
 :   m_bhist_index( 0 ), m_flag_index_locked( false ), m_flag_title_edit_in_progress( false ),
     m_ptr2widget( NULL ), m_entry_elem_title( NULL )
 {
@@ -38,9 +38,9 @@ PanelMain::PanelMain( void )
     Lifeograph::builder->get_widget( "label_header_title", m_label_elem_title );
     Lifeograph::builder->get_widget( "label_header_subtitle", m_label_elem_extra );
     Lifeograph::builder->get_widget( "button_header_back", m_button_back );
-    Lifeograph::builder->get_widget( "image_header_elem", m_image_elem );
-    Menubutton::s_builder_name = "";
-    Lifeograph::builder->get_widget_derived( "menubutton_header_elem", m_button_menu );
+    Lifeograph::builder->get_widget( "I_header_elem", m_image_elem );
+    Lifeograph::builder->get_widget( "I_header_overlay", m_image_overlay );
+    Lifeograph::builder->get_widget( "menubutton_header_elem", m_button_menu );
     Lifeograph::builder->get_widget( "alignment_header_extra_tools", m_alignment_extra_tools );
 
     m_entry_elem_title = new Gtk::Entry;
@@ -77,7 +77,7 @@ PanelMain::PanelMain( void )
 }
 
 void
-PanelMain::show( ElementShowerProto *shower )
+PanelMain::show( ElementShowerProto* shower )
 {
     if( m_flag_title_edit_in_progress )
         m_button_back->grab_focus();    // cancel editing
@@ -105,9 +105,14 @@ PanelMain::show( ElementShowerProto *shower )
 
     // ICON
     m_image_elem->set( shower->get_element()->get_icon32() );
+    update_overlay_icon();
 
     // TOOLBAR
-    m_button_menu->set_menu( shower->get_menu() );
+    if( Gtk::Menu *menu = shower->get_menu() )
+        m_button_menu->set_menu( *menu );
+    else
+        m_button_menu->unset_menu();
+
     set_extra_tools( shower->get_extra_tools() );
 
     // CONTENT
@@ -129,7 +134,7 @@ PanelMain::show( ElementShowerProto *shower )
 }
 
 void
-PanelMain::handle_logout( void )
+PanelMain::handle_logout()
 {
     if( m_flag_title_edit_in_progress )
     {
@@ -143,7 +148,7 @@ PanelMain::handle_logout( void )
 }
 
 void
-PanelMain::set_extra_tools( Gtk::Widget *tool )
+PanelMain::set_extra_tools( Gtk::Widget* tool )
 {
     if( m_alignment_extra_tools->get_child() )
         m_alignment_extra_tools->remove();
@@ -153,7 +158,7 @@ PanelMain::set_extra_tools( Gtk::Widget *tool )
 }
 
 void
-PanelMain::go_back( void )
+PanelMain::go_back()
 {
     for( unsigned int i = ( m_bhist_index - 1 + BROWSING_HISTORY_SIZE ) % BROWSING_HISTORY_SIZE;
          i != m_bhist_index;
@@ -171,7 +176,7 @@ PanelMain::go_back( void )
 }
 
 void
-PanelMain::remove_element_from_history( DiaryElement *element )
+PanelMain::remove_element_from_history( DiaryElement* element )
 {
     // TODO: this function must be improved
     for( int i = 0; i < BROWSING_HISTORY_SIZE; i++ )
@@ -182,14 +187,14 @@ PanelMain::remove_element_from_history( DiaryElement *element )
 }
 
 void
-PanelMain::clear_history( void )
+PanelMain::clear_history()
 {
     for( int i = 0; i < BROWSING_HISTORY_SIZE; i++ )
         m_browsing_history[ i ] = NULL;
 }
 
 void
-PanelMain::start_title_edit( void )
+PanelMain::start_title_edit()
 {
     if( m_flag_title_editable )
     {
@@ -208,7 +213,7 @@ PanelMain::start_title_edit( void )
 }
 
 void
-PanelMain::cancel_title_edit( void )
+PanelMain::cancel_title_edit()
 {
     if( m_flag_title_edit_in_progress )
     {
@@ -221,7 +226,7 @@ PanelMain::cancel_title_edit( void )
 }
 
 void
-PanelMain::handle_entry_title_changed( void )
+PanelMain::handle_entry_title_changed()
 {
     if( m_flag_title_edit_in_progress )
     {
@@ -235,7 +240,7 @@ PanelMain::handle_entry_title_changed( void )
 }
 
 void
-PanelMain::apply_title_edit( void )
+PanelMain::apply_title_edit()
 {
     if( m_flag_title_applicable )
     {
@@ -267,7 +272,7 @@ PanelMain::handle_entry_title_focus_out( GdkEventFocus* )
 }
 
 bool
-PanelMain::handle_entry_title_key_press( GdkEventKey *event )
+PanelMain::handle_entry_title_key_press( GdkEventKey* event )
 {
     if( event->keyval == GDK_KEY_Escape )
         m_button_back->grab_focus();    // cancel editing
