@@ -123,7 +123,7 @@ PrintOpr::init_variables( const Glib::RefPtr< Gtk::PrintContext > &print_context
     m_n_pages = 1;
     m_v_offset = 0.0;
     m_last_chapter_date = 0;
-    m_flag_chapter_round = true;    // chapter or topic round
+    m_flag_chapter_round = DiaryElement::ET_CHAPTER;    // start with chapters
 
     m_chapters = Diary::d->get_current_chapter_ctg();
     m_iter_chapter = m_chapters->rbegin();
@@ -408,12 +408,19 @@ PrintOpr::get_more()
             // CHAPTER CTG--TOPIC SWITCH
             if( m_iter_chapter == m_chapters->rend() )
             {
-                if( m_flag_chapter_round )
+                if( m_flag_chapter_round == DiaryElement::ET_CHAPTER )
                 {
                     m_chapters = Diary::d->get_topics();
                     m_iter_chapter = m_chapters->rbegin();
-                    m_flag_chapter_round = false;
-                    continue;
+                    m_flag_chapter_round = DiaryElement::ET_TOPIC;
+                    continue;   // to check if rbegin() == rend()
+                }
+                else if( m_flag_chapter_round == DiaryElement::ET_TOPIC )
+                {
+                    m_chapters = Diary::d->get_todo_groups();
+                    m_iter_chapter = m_chapters->rbegin();
+                    m_flag_chapter_round = DiaryElement::ET_TODO_GRP;
+                    continue;   // to check if rbegin() == rend()
                 }
                 else
                     break;
