@@ -290,7 +290,7 @@ EntryView::handle_drag_data_received(
 
     context->drag_finish( true, false, time );
 
-    if( Lifeograph::s_elem_dragged == NULL )
+    if( Lifeograph::s_elem_dragged == NULL || Lifeograph::s_flag_dragging == false )
         return;
 
     switch( Lifeograph::s_elem_dragged->get_type() )
