@@ -38,13 +38,13 @@ namespace LIFEO
 class EntryView : public ElementShower< Entry >
 {
     public:
-                                EntryView( void );
+                                EntryView();
 
-        void                    sync( void );
+        void                    sync();
 
-        void                    focus_tag( void );
+        void                    focus_tag();
 
-        Glib::ustring           get_title_str( void ) const
+        Glib::ustring           get_title_str() const
         {
             if( m_ptr2elem->get_date().is_ordinal() )
                 return Glib::ustring::compose( "%1: %2",
@@ -55,10 +55,10 @@ class EntryView : public ElementShower< Entry >
                                                m_ptr2elem->get_date().format_string(),
                                                m_ptr2elem->get_date().get_weekday_str() );
         }
-        Glib::ustring           get_info_str( void ) const
+        Glib::ustring           get_info_str() const
         { return Glib::ustring::compose( _( "Entry last changed on %1" ),
-                Date::format_string_do( m_ptr2elem->m_date_changed ) ); }
-        Glib::ustring           get_tip_str( void ) const
+                Date::format_string_d( m_ptr2elem->m_date_changed ) ); }
+        Glib::ustring           get_tip_str() const
         {
             return Glib::ustring::compose( "%1: <b>%2</b>\n%3: <b>%4</b>"
 #if LIFEOGRAPH_DEBUG_BUILD
@@ -74,43 +74,44 @@ class EntryView : public ElementShower< Entry >
                     );
         }
 
-        bool                    is_title_editable( void ) const
+        bool                    is_title_editable() const
         { return( ! m_ptr2elem->get_date().is_ordinal() ); }
-        Glib::ustring           get_title_edit_str( void ) const
+        Glib::ustring           get_title_edit_str() const
         { return( m_ptr2elem->get_date().format_string() ); }
         bool                    check_title_applicable( const Glib::ustring& ) const;
         bool                    apply_title( const Glib::ustring& );
 
         void                    show( Entry& );
 
-        void                    handle_login( void );
+        void                    handle_login();
 
         void                    prepare_for_hiding( Entry& );
 
-        void                    update_formatting_toolbar( void );
-        void                    update_highlight_button( void );
-        void                    toggle_comments( void );
-        void                    update_tag_widget( void )
+        void                    update_formatting_toolbar();
+        void                    update_highlight_button();
+        void                    toggle_comments();
+        void                    update_tag_widget()
         { m_widgettaglist->update(); }
-        void                    update_theme( void );
+        void                    update_theme();
 
-        TextbufferDiary*        get_buffer( void ) { return m_textview->m_buffer; }
+        TextbufferDiary*        get_buffer() { return m_textview->m_buffer; }
 
     protected:
         enum TagOperation { TO_NONE, TO_ADD, TO_REMOVE, TO_CREATE_AND_ADD };
 
-        void                    trash_entry( void );
-        void                    restore_entry( void );
-        void                    dismiss_entry( void );
-        void                    print( void );
-        void                    toggle_favoredness( void );
-        void                    reset_theme( void );
-        void                    hide( void );
-        void                    hide_before( void );
-        void                    hide_after( void );
-        void                    handle_textview_changed( void );
-        void                    handle_entry_tag_changed( void );
-        void                    handle_button_tag_clicked( void );
+        void                    trash_entry();
+        void                    restore_entry();
+        void                    dismiss_entry();
+        void                    print();
+        void                    set_todo_status( ElemStatus );
+        void                    toggle_favoredness();
+        void                    hide();
+        void                    hide_before();
+        void                    hide_after();
+        void                    handle_textview_changed();
+        void                    handle_entry_tag_changed();
+        void                    handle_button_tag_clicked();
+        void                    handle_set_theme();
         void                    handle_treeviewtags_buttonpress( GdkEventButton* );
         void                    handle_drag_data_received(
                                         const Glib::RefPtr< Gdk::DragContext >&,
@@ -119,38 +120,43 @@ class EntryView : public ElementShower< Entry >
                                         uint,
                                         guint );
 
-        void                    focus_tag_entry( void );
+        void                    focus_tag_entry();
         void                    handle_tag_entry_focus_out( GdkEventFocus* );
         void                    edit_tag_in_entry( const Tag* );
-        void                    remove_selected_tags( void );
+        void                    remove_selected_tags();
 
         // WIDGETS
-        Gtk::MenuItem           *m_menuitem_toggle_favorite;
-        Gtk::SeparatorMenuItem  *m_menuseparator_1, *m_menuseparator_2;
-        Gtk::MenuItem           *m_menuitem_reset_theme;
-        Gtk::MenuItem           *m_menuitem_trash;
-        Gtk::MenuItem           *m_menuitem_restore;
-        Gtk::MenuItem           *m_menuitem_dismiss;
+        Gtk::RadioMenuItem*     m_menuitem_todo;
+        Gtk::RadioMenuItem*     m_menuitem_done;
+        Gtk::RadioMenuItem*     m_menuitem_canceled;
+        Gtk::MenuItem*          m_menuitem_toggle_favorite;
+        Gtk::SeparatorMenuItem* m_menuseparator_1;
+        Gtk::SeparatorMenuItem* m_menuseparator_2;
+        Gtk::SeparatorMenuItem* m_menuseparator_4;
+        Gtk::MenuItem*          m_menuitem_trash;
+        Gtk::MenuItem*          m_menuitem_restore;
+        Gtk::MenuItem*          m_menuitem_dismiss;
 
-        Gtk::Button             *m_button_bold;
-        Gtk::Button             *m_button_italic;
-        Gtk::Button             *m_button_strikethrough;
-        Gtk::Button             *m_button_highlight;
-        Gtk::Label              *m_label_highlight;
-        Gtk::EventBox           *m_eventbox_highlight;      // necessary to change bg color!!
-        Gtk::Button             *m_button_add_bullet;
-        Gtk::Button             *m_button_add_checkbox;
-        Gtk::ToggleButton       *m_button_toggle_comments;
+        Gtk::Button*            m_button_bold;
+        Gtk::Button*            m_button_italic;
+        Gtk::Button*            m_button_strikethrough;
+        Gtk::Button*            m_button_highlight;
+        Gtk::Label*             m_label_highlight;
+        Gtk::EventBox*          m_eventbox_highlight;      // necessary to change bg color!!
+        Gtk::Button*            m_button_add_bullet;
+        Gtk::Button*            m_button_add_checkbox;
+        Gtk::ToggleButton*      m_button_toggle_comments;
 
-        TextviewDiary           *m_textview;
-        Gtk::Box                *m_box_tag_edit;
-        TagWidget               *m_tag_widget;
-        Gtk::Button             *m_button_tag_operation;
-        WidgetTagList           *m_widgettaglist;
-        Gtk::Box                *m_hbox_editing_toolbar;
+        TextviewDiary*          m_textview;
+        Gtk::Box*               m_box_tag_edit;
+        TagWidget*              m_tag_widget;
+        Gtk::Button*            m_button_tag_operation;
+        Gtk::Button*            m_button_set_theme;
+        WidgetTagList*          m_widgettaglist;
+        Gtk::Box*               m_hbox_editing_toolbar;
         TagOperation            m_tag_operation_cur;
 
-        Entry                   *m_entry_sync;
+        Entry*                  m_entry_sync;
 
         // ACTIONS
         Glib::RefPtr< Gtk::Action > m_action_bold;
