@@ -457,12 +457,28 @@ ViewLogin::create_new_diary()
         delete dialogsavediary;*/
     std::string path(Glib::get_home_dir() + "/new diary.diary" );
     std::string pass;
+
     if( DialogSaveDiary::launch( path, pass ) == Gtk::RESPONSE_ACCEPT )
     {
-        Diary::d->init_new( path );
-        if( pass.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
-            Diary::d->set_passphrase( pass );
-        AppWindow::p->login();
+        switch( Diary::d->init_new( path ) )
+        {
+            case LIFEO::SUCCESS:
+                if( pass.size() >= LIFEO::PASSPHRASE_MIN_SIZE )
+                    Diary::d->set_passphrase( pass );
+                AppWindow::p->login();
+                break;
+            case LIFEO::FILE_LOCKED:
+                show_info( Gtk::MESSAGE_INFO,
+                           Glib::ustring::compose( _( STRING::DIARY_LOCKED ),
+                                   Glib::ustring::compose( "<a href=\"file://%1\" title=\"%2\">%3</a>",
+                                                           Glib::path_get_dirname( m_path_cur ),
+                                                           _( "Click to open the containing folder" ),
+                                                           m_path_cur + LOCK_SUFFIX ) ) );
+                break;
+            default:
+                show_info( Gtk::MESSAGE_ERROR, _( STRING::FAILED_TO_OPEN_DIARY ) );
+                break;
+        }
     }
 }
 
