@@ -40,14 +40,14 @@ class WidgetEntryList : public Gtk::TreeView
             typedef sigc::signal< void, Tag* > Signal_void_Tag;
                                         WidgetEntryList( BaseObjectType*,
                                                          const Glib::RefPtr<Gtk::Builder>& );
-                                        ~WidgetEntryList( void );
+                                        ~WidgetEntryList();
 
-            void                        clear( void );
+            void                        clear();
             void                        present_element( const DiaryElement* );
             void                        expand_element( const DiaryElement* );
             void                        go_up( bool );
             void                        go_down( bool );
-            void                        reset_sorting_criteria( void );
+            void                        reset_sorting_criteria();
             void                        handle_sorting_criteria_changed( SortingCriteria );
 
             Gtk::TreePath               find_element( const DiaryElement* ) const;
@@ -60,6 +60,8 @@ class WidgetEntryList : public Gtk::TreeView
             int                         sort_by_change( const Gtk::TreeModel::iterator&,
                                                         const Gtk::TreeModel::iterator& );
 
+            void cell_data_func_icon( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& iter );
+
             Glib::RefPtr< Gtk::TreeStore >
                                         m_treestore;
 
@@ -71,9 +73,6 @@ class WidgetEntryList : public Gtk::TreeView
             bool                        on_key_press_event( GdkEventKey* );
 
             void                        on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& );
-            void                        on_drag_data_get(
-                                                const Glib::RefPtr< Gdk::DragContext >&,
-                                                Gtk::SelectionData&, guint, guint );
             bool                        on_drag_motion( const Glib::RefPtr< Gdk::DragContext >&,
                                                         int, int, guint );
             bool                        on_drag_drop( const Glib::RefPtr< Gdk::DragContext >&,
