@@ -32,7 +32,7 @@ using namespace LIFEO;
 
 
 // TAG WIDGET ======================================================================================
-TagWidget::TagWidget( BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder> &b )
+TagWidget::TagWidget( BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& b )
 :   EntryClear( cobject, b ), m_completion( Gtk::EntryCompletion::create() )
 {
     m_completion->set_popup_completion( true );
@@ -48,8 +48,8 @@ TagWidget::TagWidget( BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>
 }
 
 bool
-TagWidget::compare_text( const Glib::ustring &text,
-                         const Gtk::TreeModel::const_iterator &iter )
+TagWidget::compare_text( const Glib::ustring& text,
+                         const Gtk::TreeModel::const_iterator& iter )
 {
     Glib::ustring tagname = iter->get_value( PanelExtra::colrec->name );
     if( text.size() == 1 )
@@ -60,7 +60,7 @@ TagWidget::compare_text( const Glib::ustring &text,
 }
 
 void
-TagWidget::populate( const Tagset *set )
+TagWidget::populate( const Tagset* set )
 {
     m_liststore->clear();
 
@@ -76,7 +76,7 @@ TagWidget::populate( const Tagset *set )
 }
 
 void
-TagWidget::populate( void )
+TagWidget::populate()
 {
     m_liststore->clear();
 
@@ -92,7 +92,7 @@ TagWidget::populate( void )
 }
 
 // TAG LIST WIDGET =================================================================================
-WidgetTagList::WidgetTagList( BaseObjectType *cobject, const Glib::RefPtr< Gtk::Builder >& )
+WidgetTagList::WidgetTagList( BaseObjectType* cobject, const Glib::RefPtr< Gtk::Builder >& )
 :   DrawingArea( cobject ), m_ptr2entry( NULL ), m_pos_x( MARGIN ), m_pos_y( MARGIN ),
     m_hovered_tag( NULL ), m_flag_editable( true )
 {
@@ -100,7 +100,7 @@ WidgetTagList::WidgetTagList( BaseObjectType *cobject, const Glib::RefPtr< Gtk::
                 Gdk::POINTER_MOTION_MASK | Gdk::LEAVE_NOTIFY_MASK | Gdk::SCROLL_MASK );
 
     // DEFAULT FONT
-    Gtk::Button *button = new Gtk::Button;
+    Gtk::Button* button = new Gtk::Button;
     button->show();
     m_font_system = Cairo::ToyFontFace::create( button->get_style_context()->get_font().to_string(),
                                                 Cairo::FONT_SLANT_NORMAL,
@@ -112,13 +112,14 @@ WidgetTagList::WidgetTagList( BaseObjectType *cobject, const Glib::RefPtr< Gtk::
     //ICON_SIZE = Lifeograph::icons->tag_16->get_width(); // we assume that icon is a square
     /*Cairo::Format format( image_ptr_->get_has_alpha() ?
             Cairo::FORMAT_ARGB32 : Cairo::FORMAT_RGB24 );*/
-   /* m_image_surface = Cairo::ImageSurface::create( Cairo::FORMAT_ARGB32,
+    /*m_image_surface = Cairo::ImageSurface::create( Cairo::FORMAT_ARGB32,
                                                    ICON_SIZE, ICON_SIZE );
     m_image_context = Cairo::Context::create( m_image_surface );
-    Gdk::Cairo::set_source_pixbuf( m_image_context, Lifeograph::icons->tag_16, 0.0, 0.0 );
+    Gdk::Cairo::set_source_pixbuf( m_image_context, Lifeograph::icons->tag_theme_16, 0.0, 0.0 );
     m_image_context->paint();*/
 
-    m_image_surface_add = Cairo::ImageSurface::create( Cairo::FORMAT_ARGB32, 16, 16 );
+    m_image_surface_add = Cairo::ImageSurface::create( Cairo::FORMAT_ARGB32,
+                                                       ICON_SIZE, ICON_SIZE );
     m_image_context = Cairo::Context::create( m_image_surface_add );
     Gdk::Cairo::set_source_pixbuf(
             m_image_context,
@@ -128,14 +129,9 @@ WidgetTagList::WidgetTagList( BaseObjectType *cobject, const Glib::RefPtr< Gtk::
 }
 
 void
-WidgetTagList::set_entry( Entry *ptr2entry )
+WidgetTagList::set_entry( Entry* ptr2entry )
 {
     m_ptr2entry = ptr2entry;
-    m_ptr2theme = ( m_ptr2entry->get_theme_is_set() ?
-            m_ptr2entry->get_theme() : Diary::d->get_default_theme() );
-    m_font_main = Cairo::ToyFontFace::create( m_ptr2theme->font.get_family(),
-                                              Cairo::FONT_SLANT_NORMAL,
-                                              Cairo::FONT_WEIGHT_NORMAL );
     m_pos_x = MARGIN;
 
     if( Glib::RefPtr< Gdk::Window > window = get_window() )
@@ -143,14 +139,14 @@ WidgetTagList::set_entry( Entry *ptr2entry )
 }
 
 void
-WidgetTagList::update( void )
+WidgetTagList::update()
 {
     if( Glib::RefPtr< Gdk::Window > window = get_window() )
         window->invalidate( false );
 }
 
 bool
-WidgetTagList::on_scroll_event( GdkEventScroll *event )
+WidgetTagList::on_scroll_event( GdkEventScroll* event )
 {
     /*if( m_points )
     {
@@ -169,7 +165,7 @@ WidgetTagList::on_scroll_event( GdkEventScroll *event )
 }
 
 bool
-WidgetTagList::on_button_press_event( GdkEventButton *event )
+WidgetTagList::on_button_press_event( GdkEventButton* event )
 {
     if( m_ptr2entry == NULL )
         return false;
@@ -193,7 +189,7 @@ WidgetTagList::on_button_press_event( GdkEventButton *event )
 }
 
 /*bool
-WidgetTagList::on_button_release_event( GdkEventButton *event )
+WidgetTagList::on_button_release_event( GdkEventButton* event )
 {
     if( event->button == 1 )
     {
@@ -204,7 +200,7 @@ WidgetTagList::on_button_release_event( GdkEventButton *event )
 }*/
 
 bool
-WidgetTagList::on_motion_notify_event( GdkEventMotion *event )
+WidgetTagList::on_motion_notify_event( GdkEventMotion* event )
 {
     if( m_ptr2entry != NULL )
     {
@@ -246,7 +242,7 @@ WidgetTagList::on_motion_notify_event( GdkEventMotion *event )
 }
 
 bool
-WidgetTagList::on_leave_notify_event( GdkEventCrossing *event )
+WidgetTagList::on_leave_notify_event( GdkEventCrossing* event )
 {
     /*if( m_points )
     {
@@ -258,7 +254,7 @@ WidgetTagList::on_leave_notify_event( GdkEventCrossing *event )
 }
 
 void
-WidgetTagList::on_size_allocate( Gtk::Allocation &allocation )
+WidgetTagList::on_size_allocate( Gtk::Allocation& allocation )
 {
     Gtk::Widget::on_size_allocate( allocation );
     m_width = allocation.get_width();
@@ -266,13 +262,25 @@ WidgetTagList::on_size_allocate( Gtk::Allocation &allocation )
 }
 
 void
-WidgetTagList::add_item( const Cairo::RefPtr< Cairo::Context > &cr,
-                      const Cairo::RefPtr< Cairo::ImageSurface > &icon_surface,
-                      const Glib::ustring &label,
-                      const Tag *tag )
+WidgetTagList::add_item( const Cairo::RefPtr< Cairo::Context >& cr,
+                         const Glib::ustring &label,
+                         const Tag *tag )
 {
     TagItem titem;
     Cairo::TextExtents te;
+
+    if( tag->get_has_own_theme() )
+    {
+
+        m_font_theme.clear();    // is this necessary?
+        m_font_theme = Cairo::ToyFontFace::create( tag->get_theme()->font.get_family(),
+                                                   Cairo::FONT_SLANT_NORMAL,
+                                                   Cairo::FONT_WEIGHT_NORMAL );
+        cr->set_font_face( m_font_theme );
+    }
+    else
+        cr->set_font_face( m_font_system );
+
     cr->get_text_extents( label, te );
     if( m_pos_x + ICON_SIZE + LABEL_OFFSET + te.width + MARGIN > m_width )
     {
@@ -304,19 +312,40 @@ WidgetTagList::add_item( const Cairo::RefPtr< Cairo::Context > &cr,
         cr->close_path();
 
         if( tag == m_hovered_tag && m_flag_editable )
+            cr->set_line_width( 2.0 );
+
+        if( tag->get_has_own_theme() )
         {
-            Gdk::Cairo::set_source_rgba( cr, m_ptr2theme->color_highlight );
+            Gdk::Cairo::set_source_rgba( cr, tag->get_theme()->color_base );
             cr->fill_preserve();
+
+            Gdk::Cairo::set_source_rgba( cr, tag->get_theme()->color_highlight );
+            cr->stroke_preserve();
+
+            std::vector< double > dashes;
+            dashes.push_back( 10.0 );
+            dashes.push_back( 10.0 );
+
+            cr->set_dash( dashes, 0.0 );
+
+            Gdk::Cairo::set_source_rgba( cr, tag->get_theme()->color_heading );
+            cr->stroke();
+            cr->unset_dash();
+        }
+        else
+        {
+            Gdk::Cairo::set_source_rgba( cr, m_color_text_default );
+            cr->stroke();
         }
 
-        Gdk::Cairo::set_source_rgba( cr, m_color_text_default );
-        cr->stroke();
+        if( tag == m_hovered_tag && m_flag_editable )
+            cr->set_line_width( 1.0 );
     }
 
     // ICON
     if( tag == &m_add_tag_item )
     {
-        cr->set_source( icon_surface, m_pos_x, m_pos_y );
+        cr->set_source( m_image_surface_add, m_pos_x, m_pos_y );
         cr->rectangle( m_pos_x, m_pos_y, ICON_SIZE, ICON_SIZE );
         cr->clip();
         cr->paint();
@@ -326,8 +355,8 @@ WidgetTagList::add_item( const Cairo::RefPtr< Cairo::Context > &cr,
     }
 
     // LABEL
-    if( tag == m_hovered_tag && m_flag_editable )
-        Gdk::Cairo::set_source_rgba( cr, m_ptr2theme->color_text );
+    if( tag->get_has_own_theme() )
+        Gdk::Cairo::set_source_rgba( cr, tag->get_theme()->color_text );
     else
         Gdk::Cairo::set_source_rgba( cr, m_color_text_default );
 
@@ -338,7 +367,7 @@ WidgetTagList::add_item( const Cairo::RefPtr< Cairo::Context > &cr,
 }
 
 bool
-WidgetTagList::on_draw( const Cairo::RefPtr< Cairo::Context > &cr )
+WidgetTagList::on_draw( const Cairo::RefPtr< Cairo::Context >& cr )
 {
     if( m_ptr2entry == NULL )
         return false;
@@ -368,20 +397,17 @@ WidgetTagList::on_draw( const Cairo::RefPtr< Cairo::Context > &cr )
         cr->move_to( m_pos_x, m_pos_y + TEXT_HEIGHT );
         cr->show_text( _( "Not tagged" ) );
     }
-    else
-        cr->set_font_face( m_font_main );
 
     for( Tagset::const_iterator iter = ptr2tagset.begin();
          iter != ptr2tagset.end();
          ++iter )
     {
-        add_item( cr, m_image_surface, ( *iter )->get_name(), *iter );
+        add_item( cr, ( *iter )->get_name(), *iter );
     }
 
     if( m_flag_editable )
     {
-        cr->set_font_face( m_font_system );
-        add_item( cr, m_image_surface_add, _( "Add Tag" ), &m_add_tag_item );
+        add_item( cr, _( "Add Tag" ), &m_add_tag_item );
     }
 
     set_size_request( -1, m_pos_y + TEXT_HEIGHT + MARGIN );
