@@ -71,7 +71,7 @@ class UndoEdit : public Undoable
             return m_position;
         }
 
-        Glib::ustring       get_text( void ) const
+        Glib::ustring       get_text() const
         {
             return m_text;
         }
@@ -79,10 +79,10 @@ class UndoEdit : public Undoable
     protected:
         virtual void        merge( Undoable* ) = 0;
 
-        virtual void        undo( void ) = 0;
-        virtual void        redo( void ) = 0;
+        virtual void        undo() = 0;
+        virtual void        redo() = 0;
 
-        void                erase( void )
+        void                erase()
         {
             Gtk::TextIter iter_start = m_ptr2buffer->get_iter_at_offset( m_position );
             Gtk::TextIter iter_end = m_ptr2buffer->get_iter_at_offset( m_position +
@@ -90,7 +90,7 @@ class UndoEdit : public Undoable
             m_ptr2buffer->erase( iter_start, iter_end );
         }
 
-        void                insert( void )
+        void                insert()
         {
             Gtk::TextIter iterator = m_ptr2buffer->get_iter_at_offset( m_position );
             m_ptr2buffer->insert( iterator, m_text );
@@ -127,11 +127,11 @@ class UndoInsert :public UndoEdit
         }
 
     protected:
-        void                undo( void )
+        void                undo()
         {
             erase();
         }
-        void                redo( void )
+        void                redo()
         {
             insert();
         }
@@ -166,11 +166,11 @@ class UndoErase : public UndoEdit
         }
 
     protected:
-        void                undo( void )
+        void                undo()
         {
             insert();
         }
-        void                redo( void )
+        void                redo()
         {
             erase();
         }
@@ -187,7 +187,7 @@ class Link
         };
 
         virtual                     ~Link();
-        virtual void                go( void ) = 0;
+        virtual void                go() = 0;
 
         // position of link in the buffer:
         Glib::RefPtr< Gtk::TextMark >
@@ -212,9 +212,9 @@ class LinkID : public Link
                                     LinkID( const Glib::RefPtr< Gtk::TextMark >&,
                                             const Glib::RefPtr< Gtk::TextMark >&,
                                             DEID );
-        void                        go( void );
+        void                        go();
 
-        static Signal_void_Date     signal_activated( void )
+        static Signal_void_Date     signal_activated()
         { return m_signal_activated; }
 
         DEID                        m_id;
@@ -229,7 +229,7 @@ class LinkEntry : public Link
                                     LinkEntry( const Glib::RefPtr< Gtk::TextMark >&,
                                                const Glib::RefPtr< Gtk::TextMark >&,
                                                Date );
-        void                        go( void );
+        void                        go();
 
         Date                        m_date;
 
@@ -243,7 +243,7 @@ class LinkUri : public Link
                                     LinkUri( const Glib::RefPtr< Gtk::TextMark >&,
                                              const Glib::RefPtr< Gtk::TextMark >&,
                                              const std::string& );
-        void                        go( void );
+        void                        go();
 
         std::string                 m_url;
         static Gtk::TextBuffer      *m_ptr2buffer;
@@ -255,7 +255,7 @@ class LinkCheck : public Link
                                     LinkCheck( const Glib::RefPtr< Gtk::TextMark >&,
                                                const Glib::RefPtr< Gtk::TextMark >&,
                                                unsigned int = 0 );
-        void                        go( void );
+        void                        go();
 
         static const Glib::ustring  boxes;
         unsigned int                m_state_index;
@@ -284,18 +284,18 @@ class PredicateNL
 class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 {
     public:
-        typedef void ( TextbufferDiary::*ParsingApplierFn )( void );
+        typedef void ( TextbufferDiary::*ParsingApplierFn )();
 
 //      typedef sigc::signal< LinkStatus, Date >
 //                                  Signal_LinkStatus_Date;
         typedef sigc::signal< void, const Glib::ustring& >
                                     Signal_void_ustring;
 
-                                    TextbufferDiary( void );
+                                    TextbufferDiary();
         void                        set_textview( Gtk::TextView *ptr2textview )
         { m_ptr2textview = ptr2textview; }
-        void                        handle_logout( void );
-        void                        handle_login( void );
+        void                        handle_logout();
+        void                        handle_login();
 
         Link*                       get_link( int ) const;
         Link*                       get_link( const Gtk::TextIter& ) const;
@@ -303,34 +303,34 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        set_richtext( Entry* );
 
         void                        set_search_str( const Glib::ustring& );
-        bool                        select_searchstr_previous( void );
-        bool                        select_searchstr_next( void );
+        bool                        select_searchstr_previous();
+        bool                        select_searchstr_next();
 
         void                        toggle_format(  Glib::RefPtr< Tag >,
                                                     const Glib::ustring& );
-        void                        toggle_bold( void );
-        void                        toggle_italic( void );
-        void                        toggle_highlight( void );
-        void                        toggle_strikethrough( void );
+        void                        toggle_bold();
+        void                        toggle_italic();
+        void                        toggle_highlight();
+        void                        toggle_strikethrough();
 
         void                        set_comment_visibility( bool );
-        bool                        get_comment_visibility( void ) const
+        bool                        get_comment_visibility() const
         { return m_tag_comment->property_invisible(); }
 
         static void                 calculate_para_bounds( Gtk::TextIter&, Gtk::TextIter& );
         bool                        calculate_multiline_selection_bounds( Gtk::TextIter&,
                                                                           Gtk::TextIter& );
-        void                        handle_indent( void );
-        void                        handle_unindent( void );
+        void                        handle_indent();
+        void                        handle_unindent();
 
-        void                        add_bullet( void );
-        void                        add_checkbox( void );
-        void                        add_empty_line_above( void );
-        void                        remove_empty_line_above( void );
-        void                        move_line_up( void );
-        void                        move_line_down( void );
+        void                        add_bullet();
+        void                        add_checkbox();
+        void                        add_empty_line_above();
+        void                        remove_empty_line_above();
+        void                        move_line_up();
+        void                        move_line_down();
         void                        insert_link( DiaryElement* );
-        void                        insert_time_stamp( void );
+        void                        insert_time_stamp();
 
         std::string                 set_language( std::string );
 
@@ -352,41 +352,41 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
         void                        on_mark_set( const TextBuffer::iterator&,
                                                  const Glib::RefPtr< TextBuffer::Mark >& );
 
-        void                        process_space( void );
-        bool                        process_new_line( void );
+        void                        process_space();
+        bool                        process_new_line();
 
         // PARSING
         void                        parse( const Gtk::TextIter&, const Gtk::TextIter& );
-        void                        reparse( void );
+        void                        reparse();
 
         void                        apply_hidden_link_tags( Gtk::TextIter&,
                                             const Glib::RefPtr< Tag >& );
 
-        void                        apply_heading( void );
-        void                        apply_subheading( void );
-        void                        apply_bold( void );
-        void                        apply_italic( void );
-        void                        apply_strikethrough( void );
-        void                        apply_highlight( void );
-        void                        apply_comment( void );
-        void                        apply_ignore( void );
-        void                        apply_link( void );
-        void                        apply_link_date( void );
-        void                        apply_link_id( void );
-        void                        apply_check_ccl( void );
-        void                        apply_check_unf( void );
-        void                        apply_check_fin( void );
-        void                        apply_match( void );
+        void                        apply_heading();
+        void                        apply_subheading();
+        void                        apply_bold();
+        void                        apply_italic();
+        void                        apply_strikethrough();
+        void                        apply_highlight();
+        void                        apply_comment();
+        void                        apply_ignore();
+        void                        apply_link();
+        void                        apply_link_date();
+        void                        apply_link_id();
+        void                        apply_check_ccl();
+        void                        apply_check_unf();
+        void                        apply_check_fin();
+        void                        apply_match();
         void                        apply_markup( const Glib::RefPtr<Tag>& );
 
         gunichar                    get_char_at( int );
 
-        void                        handle_word( void );
+        void                        handle_word();
 
-        void                        handle_spellcheck_toggled( void );
+        void                        handle_spellcheck_toggled();
         void                        handle_language_changed( const std::string&,
                                                              const Gtk::RadioMenuItem* );
-        Gtk::Menu*                  build_languages_menu( void );
+        Gtk::Menu*                  build_languages_menu();
         void                        add_suggestion_menus( const Glib::ustring&, Gtk::Menu* );
         void                        ignore_misspelled_word( const Glib::ustring& );
         void                        replace_misspelled_word( const Glib::ustring& );
@@ -401,10 +401,10 @@ class TextbufferDiary : public Gtk::TextBuffer, public EntryParser
 
         // LINKS
         void                        clear_links( int, int );
-        void                        clear_links( void );
+        void                        clear_links();
 
         void                        clear_images( int, int& );
-        void                        clear_images( void );
+        void                        clear_images();
         bool                        update_thumbnail_width( int );
 
         // TAGS
@@ -468,7 +468,7 @@ class TextviewDiary : public Gtk::TextView
         TextbufferDiary             *m_buffer;
 
     protected:
-        void                        update_link( void );
+        void                        update_link();
         virtual bool                on_motion_notify_event( GdkEventMotion* );
         virtual bool                on_button_press_event( GdkEventButton* );
         virtual bool                on_button_release_event( GdkEventButton* );
